# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .act_action import ActAction
    from .act_action_data import ActActionData
    from .action import Action
    from .action_block import ActionBlock
    from .action_block_data_schema import ActionBlockDataSchema
    from .action_block_parameters_item import (
        ActionBlockParametersItem,
        ActionBlockParametersItem_AwsSecret,
        ActionBlockParametersItem_AzureSecret,
        ActionBlockParametersItem_AzureVaultCredential,
        ActionBlockParametersItem_BitwardenCreditCardData,
        ActionBlockParametersItem_BitwardenLoginCredential,
        ActionBlockParametersItem_BitwardenSensitiveInformation,
        ActionBlockParametersItem_Context,
        ActionBlockParametersItem_Credential,
        ActionBlockParametersItem_Onepassword,
        ActionBlockParametersItem_Output,
        ActionBlockParametersItem_Workflow,
    )
    from .action_block_yaml import ActionBlockYaml
    from .action_status import ActionStatus
    from .action_type import ActionType
    from .artifact import Artifact
    from .artifact_type import ArtifactType
    from .aws_secret_parameter import AwsSecretParameter
    from .aws_secret_parameter_yaml import AwsSecretParameterYaml
    from .azure_secret_parameter import AzureSecretParameter
    from .azure_vault_credential_parameter import AzureVaultCredentialParameter
    from .azure_vault_credential_parameter_yaml import AzureVaultCredentialParameterYaml
    from .billing_state_response import BillingStateResponse
    from .bitwarden_credit_card_data_parameter import BitwardenCreditCardDataParameter
    from .bitwarden_credit_card_data_parameter_yaml import BitwardenCreditCardDataParameterYaml
    from .bitwarden_login_credential_parameter import BitwardenLoginCredentialParameter
    from .bitwarden_login_credential_parameter_yaml import BitwardenLoginCredentialParameterYaml
    from .bitwarden_sensitive_information_parameter import BitwardenSensitiveInformationParameter
    from .bitwarden_sensitive_information_parameter_yaml import BitwardenSensitiveInformationParameterYaml
    from .block_type import BlockType
    from .branch_condition import BranchCondition
    from .branch_condition_criteria import (
        BranchConditionCriteria,
        BranchConditionCriteria_Jinja2Template,
        BranchConditionCriteria_Prompt,
    )
    from .branch_condition_yaml import BranchConditionYaml
    from .branch_criteria_yaml import BranchCriteriaYaml
    from .branch_criteria_yaml_criteria_type import BranchCriteriaYamlCriteriaType
    from .browser_profile import BrowserProfile
    from .browser_session_response import BrowserSessionResponse
    from .change_tier_response import ChangeTierResponse
    from .checkout_session_response import CheckoutSessionResponse
    from .clear_cache_response import ClearCacheResponse
    from .click_action import ClickAction
    from .click_action_data import ClickActionData
    from .click_context import ClickContext
    from .code_block import CodeBlock
    from .code_block_parameters_item import (
        CodeBlockParametersItem,
        CodeBlockParametersItem_AwsSecret,
        CodeBlockParametersItem_AzureSecret,
        CodeBlockParametersItem_AzureVaultCredential,
        CodeBlockParametersItem_BitwardenCreditCardData,
        CodeBlockParametersItem_BitwardenLoginCredential,
        CodeBlockParametersItem_BitwardenSensitiveInformation,
        CodeBlockParametersItem_Context,
        CodeBlockParametersItem_Credential,
        CodeBlockParametersItem_Onepassword,
        CodeBlockParametersItem_Output,
        CodeBlockParametersItem_Workflow,
    )
    from .code_block_yaml import CodeBlockYaml
    from .conditional_block import ConditionalBlock
    from .conditional_block_yaml import ConditionalBlockYaml
    from .context_parameter import ContextParameter
    from .context_parameter_source import (
        ContextParameterSource,
        ContextParameterSource_AwsSecret,
        ContextParameterSource_AzureSecret,
        ContextParameterSource_AzureVaultCredential,
        ContextParameterSource_BitwardenCreditCardData,
        ContextParameterSource_BitwardenLoginCredential,
        ContextParameterSource_BitwardenSensitiveInformation,
        ContextParameterSource_Context,
        ContextParameterSource_Credential,
        ContextParameterSource_Onepassword,
        ContextParameterSource_Output,
        ContextParameterSource_Workflow,
    )
    from .context_parameter_value import ContextParameterValue
    from .context_parameter_yaml import ContextParameterYaml
    from .create_credential_request import CreateCredentialRequest
    from .create_credential_request_credential import CreateCredentialRequestCredential
    from .create_script_response import CreateScriptResponse
    from .credential_parameter import CredentialParameter
    from .credential_parameter_yaml import CredentialParameterYaml
    from .credential_response import CredentialResponse
    from .credential_response_credential import CredentialResponseCredential
    from .credential_type_output import CredentialTypeOutput
    from .credit_card_credential_response import CreditCardCredentialResponse
    from .download_to_s3block import DownloadToS3Block
    from .download_to_s3block_yaml import DownloadToS3BlockYaml
    from .extensions import Extensions
    from .extract_action import ExtractAction
    from .extract_action_data import ExtractActionData
    from .extract_action_extract_schema import ExtractActionExtractSchema
    from .extraction_block import ExtractionBlock
    from .extraction_block_data_schema import ExtractionBlockDataSchema
    from .extraction_block_parameters_item import (
        ExtractionBlockParametersItem,
        ExtractionBlockParametersItem_AwsSecret,
        ExtractionBlockParametersItem_AzureSecret,
        ExtractionBlockParametersItem_AzureVaultCredential,
        ExtractionBlockParametersItem_BitwardenCreditCardData,
        ExtractionBlockParametersItem_BitwardenLoginCredential,
        ExtractionBlockParametersItem_BitwardenSensitiveInformation,
        ExtractionBlockParametersItem_Context,
        ExtractionBlockParametersItem_Credential,
        ExtractionBlockParametersItem_Onepassword,
        ExtractionBlockParametersItem_Output,
        ExtractionBlockParametersItem_Workflow,
    )
    from .extraction_block_yaml import ExtractionBlockYaml
    from .extraction_block_yaml_data_schema import ExtractionBlockYamlDataSchema
    from .file_download_block import FileDownloadBlock
    from .file_download_block_data_schema import FileDownloadBlockDataSchema
    from .file_download_block_parameters_item import (
        FileDownloadBlockParametersItem,
        FileDownloadBlockParametersItem_AwsSecret,
        FileDownloadBlockParametersItem_AzureSecret,
        FileDownloadBlockParametersItem_AzureVaultCredential,
        FileDownloadBlockParametersItem_BitwardenCreditCardData,
        FileDownloadBlockParametersItem_BitwardenLoginCredential,
        FileDownloadBlockParametersItem_BitwardenSensitiveInformation,
        FileDownloadBlockParametersItem_Context,
        FileDownloadBlockParametersItem_Credential,
        FileDownloadBlockParametersItem_Onepassword,
        FileDownloadBlockParametersItem_Output,
        FileDownloadBlockParametersItem_Workflow,
    )
    from .file_download_block_yaml import FileDownloadBlockYaml
    from .file_encoding import FileEncoding
    from .file_info import FileInfo
    from .file_node import FileNode
    from .file_parser_block import FileParserBlock
    from .file_parser_block_yaml import FileParserBlockYaml
    from .file_storage_type import FileStorageType
    from .file_type import FileType
    from .file_upload_block import FileUploadBlock
    from .file_upload_block_yaml import FileUploadBlockYaml
    from .for_loop_block import ForLoopBlock
    from .for_loop_block_data_schema import ForLoopBlockDataSchema
    from .for_loop_block_loop_blocks_item import (
        ForLoopBlockLoopBlocksItem,
        ForLoopBlockLoopBlocksItem_Action,
        ForLoopBlockLoopBlocksItem_Code,
        ForLoopBlockLoopBlocksItem_Conditional,
        ForLoopBlockLoopBlocksItem_DownloadToS3,
        ForLoopBlockLoopBlocksItem_Extraction,
        ForLoopBlockLoopBlocksItem_FileDownload,
        ForLoopBlockLoopBlocksItem_FileUpload,
        ForLoopBlockLoopBlocksItem_FileUrlParser,
        ForLoopBlockLoopBlocksItem_ForLoop,
        ForLoopBlockLoopBlocksItem_GotoUrl,
        ForLoopBlockLoopBlocksItem_HttpRequest,
        ForLoopBlockLoopBlocksItem_HumanInteraction,
        ForLoopBlockLoopBlocksItem_Login,
        ForLoopBlockLoopBlocksItem_Navigation,
        ForLoopBlockLoopBlocksItem_PdfParser,
        ForLoopBlockLoopBlocksItem_PrintPage,
        ForLoopBlockLoopBlocksItem_SendEmail,
        ForLoopBlockLoopBlocksItem_Task,
        ForLoopBlockLoopBlocksItem_TaskV2,
        ForLoopBlockLoopBlocksItem_TextPrompt,
        ForLoopBlockLoopBlocksItem_UploadToS3,
        ForLoopBlockLoopBlocksItem_Validation,
        ForLoopBlockLoopBlocksItem_Wait,
    )
    from .for_loop_block_loop_over import (
        ForLoopBlockLoopOver,
        ForLoopBlockLoopOver_AwsSecret,
        ForLoopBlockLoopOver_AzureSecret,
        ForLoopBlockLoopOver_AzureVaultCredential,
        ForLoopBlockLoopOver_BitwardenCreditCardData,
        ForLoopBlockLoopOver_BitwardenLoginCredential,
        ForLoopBlockLoopOver_BitwardenSensitiveInformation,
        ForLoopBlockLoopOver_Context,
        ForLoopBlockLoopOver_Credential,
        ForLoopBlockLoopOver_Onepassword,
        ForLoopBlockLoopOver_Output,
        ForLoopBlockLoopOver_Workflow,
    )
    from .for_loop_block_yaml import ForLoopBlockYaml
    from .for_loop_block_yaml_data_schema import ForLoopBlockYamlDataSchema
    from .for_loop_block_yaml_loop_blocks_item import (
        ForLoopBlockYamlLoopBlocksItem,
        ForLoopBlockYamlLoopBlocksItem_Action,
        ForLoopBlockYamlLoopBlocksItem_Code,
        ForLoopBlockYamlLoopBlocksItem_Conditional,
        ForLoopBlockYamlLoopBlocksItem_DownloadToS3,
        ForLoopBlockYamlLoopBlocksItem_Extraction,
        ForLoopBlockYamlLoopBlocksItem_FileDownload,
        ForLoopBlockYamlLoopBlocksItem_FileUpload,
        ForLoopBlockYamlLoopBlocksItem_FileUrlParser,
        ForLoopBlockYamlLoopBlocksItem_ForLoop,
        ForLoopBlockYamlLoopBlocksItem_GotoUrl,
        ForLoopBlockYamlLoopBlocksItem_HttpRequest,
        ForLoopBlockYamlLoopBlocksItem_HumanInteraction,
        ForLoopBlockYamlLoopBlocksItem_Login,
        ForLoopBlockYamlLoopBlocksItem_Navigation,
        ForLoopBlockYamlLoopBlocksItem_PdfParser,
        ForLoopBlockYamlLoopBlocksItem_PrintPage,
        ForLoopBlockYamlLoopBlocksItem_SendEmail,
        ForLoopBlockYamlLoopBlocksItem_Task,
        ForLoopBlockYamlLoopBlocksItem_TaskV2,
        ForLoopBlockYamlLoopBlocksItem_TextPrompt,
        ForLoopBlockYamlLoopBlocksItem_UploadToS3,
        ForLoopBlockYamlLoopBlocksItem_Validation,
        ForLoopBlockYamlLoopBlocksItem_Wait,
    )
    from .geo_target import GeoTarget
    from .get_run_response import (
        GetRunResponse,
        GetRunResponse_AnthropicCua,
        GetRunResponse_OpenaiCua,
        GetRunResponse_TaskV1,
        GetRunResponse_TaskV2,
        GetRunResponse_UiTars,
        GetRunResponse_WorkflowRun,
    )
    from .http_request_block import HttpRequestBlock
    from .http_request_block_parameters_item import (
        HttpRequestBlockParametersItem,
        HttpRequestBlockParametersItem_AwsSecret,
        HttpRequestBlockParametersItem_AzureSecret,
        HttpRequestBlockParametersItem_AzureVaultCredential,
        HttpRequestBlockParametersItem_BitwardenCreditCardData,
        HttpRequestBlockParametersItem_BitwardenLoginCredential,
        HttpRequestBlockParametersItem_BitwardenSensitiveInformation,
        HttpRequestBlockParametersItem_Context,
        HttpRequestBlockParametersItem_Credential,
        HttpRequestBlockParametersItem_Onepassword,
        HttpRequestBlockParametersItem_Output,
        HttpRequestBlockParametersItem_Workflow,
    )
    from .http_request_block_yaml import HttpRequestBlockYaml
    from .http_validation_error import HttpValidationError
    from .human_interaction_block import HumanInteractionBlock
    from .human_interaction_block_data_schema import HumanInteractionBlockDataSchema
    from .human_interaction_block_parameters_item import (
        HumanInteractionBlockParametersItem,
        HumanInteractionBlockParametersItem_AwsSecret,
        HumanInteractionBlockParametersItem_AzureSecret,
        HumanInteractionBlockParametersItem_AzureVaultCredential,
        HumanInteractionBlockParametersItem_BitwardenCreditCardData,
        HumanInteractionBlockParametersItem_BitwardenLoginCredential,
        HumanInteractionBlockParametersItem_BitwardenSensitiveInformation,
        HumanInteractionBlockParametersItem_Context,
        HumanInteractionBlockParametersItem_Credential,
        HumanInteractionBlockParametersItem_Onepassword,
        HumanInteractionBlockParametersItem_Output,
        HumanInteractionBlockParametersItem_Workflow,
    )
    from .human_interaction_block_yaml import HumanInteractionBlockYaml
    from .input_or_select_context import InputOrSelectContext
    from .input_text_action import InputTextAction
    from .input_text_action_data import InputTextActionData
    from .jinja_branch_criteria import JinjaBranchCriteria
    from .locate_element_action import LocateElementAction
    from .login_block import LoginBlock
    from .login_block_data_schema import LoginBlockDataSchema
    from .login_block_parameters_item import (
        LoginBlockParametersItem,
        LoginBlockParametersItem_AwsSecret,
        LoginBlockParametersItem_AzureSecret,
        LoginBlockParametersItem_AzureVaultCredential,
        LoginBlockParametersItem_BitwardenCreditCardData,
        LoginBlockParametersItem_BitwardenLoginCredential,
        LoginBlockParametersItem_BitwardenSensitiveInformation,
        LoginBlockParametersItem_Context,
        LoginBlockParametersItem_Credential,
        LoginBlockParametersItem_Onepassword,
        LoginBlockParametersItem_Output,
        LoginBlockParametersItem_Workflow,
    )
    from .login_block_yaml import LoginBlockYaml
    from .navigation_block import NavigationBlock
    from .navigation_block_data_schema import NavigationBlockDataSchema
    from .navigation_block_parameters_item import (
        NavigationBlockParametersItem,
        NavigationBlockParametersItem_AwsSecret,
        NavigationBlockParametersItem_AzureSecret,
        NavigationBlockParametersItem_AzureVaultCredential,
        NavigationBlockParametersItem_BitwardenCreditCardData,
        NavigationBlockParametersItem_BitwardenLoginCredential,
        NavigationBlockParametersItem_BitwardenSensitiveInformation,
        NavigationBlockParametersItem_Context,
        NavigationBlockParametersItem_Credential,
        NavigationBlockParametersItem_Onepassword,
        NavigationBlockParametersItem_Output,
        NavigationBlockParametersItem_Workflow,
    )
    from .navigation_block_yaml import NavigationBlockYaml
    from .non_empty_credit_card_credential import NonEmptyCreditCardCredential
    from .non_empty_password_credential import NonEmptyPasswordCredential
    from .one_password_credential_parameter import OnePasswordCredentialParameter
    from .one_password_credential_parameter_yaml import OnePasswordCredentialParameterYaml
    from .otp_type import OtpType
    from .output_parameter import OutputParameter
    from .output_parameter_yaml import OutputParameterYaml
    from .password_credential_response import PasswordCredentialResponse
    from .pdf_format import PdfFormat
    from .pdf_parser_block import PdfParserBlock
    from .pdf_parser_block_yaml import PdfParserBlockYaml
    from .persistent_browser_type import PersistentBrowserType
    from .plan_tier import PlanTier
    from .portal_session_response import PortalSessionResponse
    from .print_page_block import PrintPageBlock
    from .print_page_block_parameters_item import (
        PrintPageBlockParametersItem,
        PrintPageBlockParametersItem_AwsSecret,
        PrintPageBlockParametersItem_AzureSecret,
        PrintPageBlockParametersItem_AzureVaultCredential,
        PrintPageBlockParametersItem_BitwardenCreditCardData,
        PrintPageBlockParametersItem_BitwardenLoginCredential,
        PrintPageBlockParametersItem_BitwardenSensitiveInformation,
        PrintPageBlockParametersItem_Context,
        PrintPageBlockParametersItem_Credential,
        PrintPageBlockParametersItem_Onepassword,
        PrintPageBlockParametersItem_Output,
        PrintPageBlockParametersItem_Workflow,
    )
    from .print_page_block_yaml import PrintPageBlockYaml
    from .prompt_action import PromptAction
    from .prompt_branch_criteria import PromptBranchCriteria
    from .proxy_location import ProxyLocation
    from .retry_run_webhook_request import RetryRunWebhookRequest
    from .run_engine import RunEngine
    from .run_sdk_action_request_action import (
        RunSdkActionRequestAction,
        RunSdkActionRequestAction_AiAct,
        RunSdkActionRequestAction_AiClick,
        RunSdkActionRequestAction_AiInputText,
        RunSdkActionRequestAction_AiSelectOption,
        RunSdkActionRequestAction_AiUploadFile,
        RunSdkActionRequestAction_Extract,
        RunSdkActionRequestAction_LocateElement,
        RunSdkActionRequestAction_Prompt,
        RunSdkActionRequestAction_Validate,
    )
    from .run_sdk_action_response import RunSdkActionResponse
    from .run_status import RunStatus
    from .script import Script
    from .script_file_create import ScriptFileCreate
    from .script_run_response import ScriptRunResponse
    from .secret_credential import SecretCredential
    from .secret_credential_response import SecretCredentialResponse
    from .select_option import SelectOption
    from .select_option_action import SelectOptionAction
    from .select_option_action_data import SelectOptionActionData
    from .send_email_block import SendEmailBlock
    from .send_email_block_yaml import SendEmailBlockYaml
    from .skyvern_forge_sdk_schemas_credentials_credential_type import SkyvernForgeSdkSchemasCredentialsCredentialType
    from .skyvern_schemas_run_blocks_credential_type import SkyvernSchemasRunBlocksCredentialType
    from .task_block import TaskBlock
    from .task_block_data_schema import TaskBlockDataSchema
    from .task_block_parameters_item import (
        TaskBlockParametersItem,
        TaskBlockParametersItem_AwsSecret,
        TaskBlockParametersItem_AzureSecret,
        TaskBlockParametersItem_AzureVaultCredential,
        TaskBlockParametersItem_BitwardenCreditCardData,
        TaskBlockParametersItem_BitwardenLoginCredential,
        TaskBlockParametersItem_BitwardenSensitiveInformation,
        TaskBlockParametersItem_Context,
        TaskBlockParametersItem_Credential,
        TaskBlockParametersItem_Onepassword,
        TaskBlockParametersItem_Output,
        TaskBlockParametersItem_Workflow,
    )
    from .task_block_yaml import TaskBlockYaml
    from .task_block_yaml_data_schema import TaskBlockYamlDataSchema
    from .task_run_request import TaskRunRequest
    from .task_run_request_data_extraction_schema import TaskRunRequestDataExtractionSchema
    from .task_run_request_proxy_location import TaskRunRequestProxyLocation
    from .task_run_response import TaskRunResponse
    from .task_run_response_output import TaskRunResponseOutput
    from .task_v2block import TaskV2Block
    from .task_v2block_yaml import TaskV2BlockYaml
    from .text_prompt_block import TextPromptBlock
    from .text_prompt_block_parameters_item import (
        TextPromptBlockParametersItem,
        TextPromptBlockParametersItem_AwsSecret,
        TextPromptBlockParametersItem_AzureSecret,
        TextPromptBlockParametersItem_AzureVaultCredential,
        TextPromptBlockParametersItem_BitwardenCreditCardData,
        TextPromptBlockParametersItem_BitwardenLoginCredential,
        TextPromptBlockParametersItem_BitwardenSensitiveInformation,
        TextPromptBlockParametersItem_Context,
        TextPromptBlockParametersItem_Credential,
        TextPromptBlockParametersItem_Onepassword,
        TextPromptBlockParametersItem_Output,
        TextPromptBlockParametersItem_Workflow,
    )
    from .text_prompt_block_yaml import TextPromptBlockYaml
    from .thought import Thought
    from .thought_scenario import ThoughtScenario
    from .thought_type import ThoughtType
    from .totp_code import TotpCode
    from .totp_type import TotpType
    from .upload_file_action import UploadFileAction
    from .upload_file_action_data import UploadFileActionData
    from .upload_file_response import UploadFileResponse
    from .upload_to_s3block import UploadToS3Block
    from .upload_to_s3block_yaml import UploadToS3BlockYaml
    from .url_block import UrlBlock
    from .url_block_data_schema import UrlBlockDataSchema
    from .url_block_parameters_item import (
        UrlBlockParametersItem,
        UrlBlockParametersItem_AwsSecret,
        UrlBlockParametersItem_AzureSecret,
        UrlBlockParametersItem_AzureVaultCredential,
        UrlBlockParametersItem_BitwardenCreditCardData,
        UrlBlockParametersItem_BitwardenLoginCredential,
        UrlBlockParametersItem_BitwardenSensitiveInformation,
        UrlBlockParametersItem_Context,
        UrlBlockParametersItem_Credential,
        UrlBlockParametersItem_Onepassword,
        UrlBlockParametersItem_Output,
        UrlBlockParametersItem_Workflow,
    )
    from .url_block_yaml import UrlBlockYaml
    from .user_defined_error import UserDefinedError
    from .validate_action import ValidateAction
    from .validation_block import ValidationBlock
    from .validation_block_data_schema import ValidationBlockDataSchema
    from .validation_block_parameters_item import (
        ValidationBlockParametersItem,
        ValidationBlockParametersItem_AwsSecret,
        ValidationBlockParametersItem_AzureSecret,
        ValidationBlockParametersItem_AzureVaultCredential,
        ValidationBlockParametersItem_BitwardenCreditCardData,
        ValidationBlockParametersItem_BitwardenLoginCredential,
        ValidationBlockParametersItem_BitwardenSensitiveInformation,
        ValidationBlockParametersItem_Context,
        ValidationBlockParametersItem_Credential,
        ValidationBlockParametersItem_Onepassword,
        ValidationBlockParametersItem_Output,
        ValidationBlockParametersItem_Workflow,
    )
    from .validation_block_yaml import ValidationBlockYaml
    from .validation_error import ValidationError
    from .validation_error_loc_item import ValidationErrorLocItem
    from .wait_block import WaitBlock
    from .wait_block_parameters_item import (
        WaitBlockParametersItem,
        WaitBlockParametersItem_AwsSecret,
        WaitBlockParametersItem_AzureSecret,
        WaitBlockParametersItem_AzureVaultCredential,
        WaitBlockParametersItem_BitwardenCreditCardData,
        WaitBlockParametersItem_BitwardenLoginCredential,
        WaitBlockParametersItem_BitwardenSensitiveInformation,
        WaitBlockParametersItem_Context,
        WaitBlockParametersItem_Credential,
        WaitBlockParametersItem_Onepassword,
        WaitBlockParametersItem_Output,
        WaitBlockParametersItem_Workflow,
    )
    from .wait_block_yaml import WaitBlockYaml
    from .workflow import Workflow
    from .workflow_create_yaml_request import WorkflowCreateYamlRequest
    from .workflow_create_yaml_request_proxy_location import WorkflowCreateYamlRequestProxyLocation
    from .workflow_definition import WorkflowDefinition
    from .workflow_definition_blocks_item import (
        WorkflowDefinitionBlocksItem,
        WorkflowDefinitionBlocksItem_Action,
        WorkflowDefinitionBlocksItem_Code,
        WorkflowDefinitionBlocksItem_Conditional,
        WorkflowDefinitionBlocksItem_DownloadToS3,
        WorkflowDefinitionBlocksItem_Extraction,
        WorkflowDefinitionBlocksItem_FileDownload,
        WorkflowDefinitionBlocksItem_FileUpload,
        WorkflowDefinitionBlocksItem_FileUrlParser,
        WorkflowDefinitionBlocksItem_ForLoop,
        WorkflowDefinitionBlocksItem_GotoUrl,
        WorkflowDefinitionBlocksItem_HttpRequest,
        WorkflowDefinitionBlocksItem_HumanInteraction,
        WorkflowDefinitionBlocksItem_Login,
        WorkflowDefinitionBlocksItem_Navigation,
        WorkflowDefinitionBlocksItem_PdfParser,
        WorkflowDefinitionBlocksItem_PrintPage,
        WorkflowDefinitionBlocksItem_SendEmail,
        WorkflowDefinitionBlocksItem_Task,
        WorkflowDefinitionBlocksItem_TaskV2,
        WorkflowDefinitionBlocksItem_TextPrompt,
        WorkflowDefinitionBlocksItem_UploadToS3,
        WorkflowDefinitionBlocksItem_Validation,
        WorkflowDefinitionBlocksItem_Wait,
    )
    from .workflow_definition_parameters_item import (
        WorkflowDefinitionParametersItem,
        WorkflowDefinitionParametersItem_AwsSecret,
        WorkflowDefinitionParametersItem_AzureSecret,
        WorkflowDefinitionParametersItem_AzureVaultCredential,
        WorkflowDefinitionParametersItem_BitwardenCreditCardData,
        WorkflowDefinitionParametersItem_BitwardenLoginCredential,
        WorkflowDefinitionParametersItem_BitwardenSensitiveInformation,
        WorkflowDefinitionParametersItem_Context,
        WorkflowDefinitionParametersItem_Credential,
        WorkflowDefinitionParametersItem_Onepassword,
        WorkflowDefinitionParametersItem_Output,
        WorkflowDefinitionParametersItem_Workflow,
    )
    from .workflow_definition_yaml import WorkflowDefinitionYaml
    from .workflow_definition_yaml_blocks_item import (
        WorkflowDefinitionYamlBlocksItem,
        WorkflowDefinitionYamlBlocksItem_Action,
        WorkflowDefinitionYamlBlocksItem_Code,
        WorkflowDefinitionYamlBlocksItem_Conditional,
        WorkflowDefinitionYamlBlocksItem_DownloadToS3,
        WorkflowDefinitionYamlBlocksItem_Extraction,
        WorkflowDefinitionYamlBlocksItem_FileDownload,
        WorkflowDefinitionYamlBlocksItem_FileUpload,
        WorkflowDefinitionYamlBlocksItem_FileUrlParser,
        WorkflowDefinitionYamlBlocksItem_ForLoop,
        WorkflowDefinitionYamlBlocksItem_GotoUrl,
        WorkflowDefinitionYamlBlocksItem_HttpRequest,
        WorkflowDefinitionYamlBlocksItem_HumanInteraction,
        WorkflowDefinitionYamlBlocksItem_Login,
        WorkflowDefinitionYamlBlocksItem_Navigation,
        WorkflowDefinitionYamlBlocksItem_PdfParser,
        WorkflowDefinitionYamlBlocksItem_PrintPage,
        WorkflowDefinitionYamlBlocksItem_SendEmail,
        WorkflowDefinitionYamlBlocksItem_Task,
        WorkflowDefinitionYamlBlocksItem_TaskV2,
        WorkflowDefinitionYamlBlocksItem_TextPrompt,
        WorkflowDefinitionYamlBlocksItem_UploadToS3,
        WorkflowDefinitionYamlBlocksItem_Validation,
        WorkflowDefinitionYamlBlocksItem_Wait,
    )
    from .workflow_definition_yaml_parameters_item import (
        WorkflowDefinitionYamlParametersItem,
        WorkflowDefinitionYamlParametersItem_AwsSecret,
        WorkflowDefinitionYamlParametersItem_AzureVaultCredential,
        WorkflowDefinitionYamlParametersItem_BitwardenCreditCardData,
        WorkflowDefinitionYamlParametersItem_BitwardenLoginCredential,
        WorkflowDefinitionYamlParametersItem_BitwardenSensitiveInformation,
        WorkflowDefinitionYamlParametersItem_Context,
        WorkflowDefinitionYamlParametersItem_Credential,
        WorkflowDefinitionYamlParametersItem_Onepassword,
        WorkflowDefinitionYamlParametersItem_Output,
        WorkflowDefinitionYamlParametersItem_Workflow,
    )
    from .workflow_parameter import WorkflowParameter
    from .workflow_parameter_default_value import WorkflowParameterDefaultValue
    from .workflow_parameter_type import WorkflowParameterType
    from .workflow_parameter_yaml import WorkflowParameterYaml
    from .workflow_parameter_yaml_default_value import WorkflowParameterYamlDefaultValue
    from .workflow_proxy_location import WorkflowProxyLocation
    from .workflow_request import WorkflowRequest
    from .workflow_run import WorkflowRun
    from .workflow_run_block import WorkflowRunBlock
    from .workflow_run_block_data_schema import WorkflowRunBlockDataSchema
    from .workflow_run_block_navigation_payload import WorkflowRunBlockNavigationPayload
    from .workflow_run_block_output import WorkflowRunBlockOutput
    from .workflow_run_proxy_location import WorkflowRunProxyLocation
    from .workflow_run_request import WorkflowRunRequest
    from .workflow_run_request_proxy_location import WorkflowRunRequestProxyLocation
    from .workflow_run_response import WorkflowRunResponse
    from .workflow_run_response_output import WorkflowRunResponseOutput
    from .workflow_run_status import WorkflowRunStatus
    from .workflow_run_timeline import WorkflowRunTimeline
    from .workflow_run_timeline_type import WorkflowRunTimelineType
    from .workflow_status import WorkflowStatus
_dynamic_imports: typing.Dict[str, str] = {
    "ActAction": ".act_action",
    "ActActionData": ".act_action_data",
    "Action": ".action",
    "ActionBlock": ".action_block",
    "ActionBlockDataSchema": ".action_block_data_schema",
    "ActionBlockParametersItem": ".action_block_parameters_item",
    "ActionBlockParametersItem_AwsSecret": ".action_block_parameters_item",
    "ActionBlockParametersItem_AzureSecret": ".action_block_parameters_item",
    "ActionBlockParametersItem_AzureVaultCredential": ".action_block_parameters_item",
    "ActionBlockParametersItem_BitwardenCreditCardData": ".action_block_parameters_item",
    "ActionBlockParametersItem_BitwardenLoginCredential": ".action_block_parameters_item",
    "ActionBlockParametersItem_BitwardenSensitiveInformation": ".action_block_parameters_item",
    "ActionBlockParametersItem_Context": ".action_block_parameters_item",
    "ActionBlockParametersItem_Credential": ".action_block_parameters_item",
    "ActionBlockParametersItem_Onepassword": ".action_block_parameters_item",
    "ActionBlockParametersItem_Output": ".action_block_parameters_item",
    "ActionBlockParametersItem_Workflow": ".action_block_parameters_item",
    "ActionBlockYaml": ".action_block_yaml",
    "ActionStatus": ".action_status",
    "ActionType": ".action_type",
    "Artifact": ".artifact",
    "ArtifactType": ".artifact_type",
    "AwsSecretParameter": ".aws_secret_parameter",
    "AwsSecretParameterYaml": ".aws_secret_parameter_yaml",
    "AzureSecretParameter": ".azure_secret_parameter",
    "AzureVaultCredentialParameter": ".azure_vault_credential_parameter",
    "AzureVaultCredentialParameterYaml": ".azure_vault_credential_parameter_yaml",
    "BillingStateResponse": ".billing_state_response",
    "BitwardenCreditCardDataParameter": ".bitwarden_credit_card_data_parameter",
    "BitwardenCreditCardDataParameterYaml": ".bitwarden_credit_card_data_parameter_yaml",
    "BitwardenLoginCredentialParameter": ".bitwarden_login_credential_parameter",
    "BitwardenLoginCredentialParameterYaml": ".bitwarden_login_credential_parameter_yaml",
    "BitwardenSensitiveInformationParameter": ".bitwarden_sensitive_information_parameter",
    "BitwardenSensitiveInformationParameterYaml": ".bitwarden_sensitive_information_parameter_yaml",
    "BlockType": ".block_type",
    "BranchCondition": ".branch_condition",
    "BranchConditionCriteria": ".branch_condition_criteria",
    "BranchConditionCriteria_Jinja2Template": ".branch_condition_criteria",
    "BranchConditionCriteria_Prompt": ".branch_condition_criteria",
    "BranchConditionYaml": ".branch_condition_yaml",
    "BranchCriteriaYaml": ".branch_criteria_yaml",
    "BranchCriteriaYamlCriteriaType": ".branch_criteria_yaml_criteria_type",
    "BrowserProfile": ".browser_profile",
    "BrowserSessionResponse": ".browser_session_response",
    "ChangeTierResponse": ".change_tier_response",
    "CheckoutSessionResponse": ".checkout_session_response",
    "ClearCacheResponse": ".clear_cache_response",
    "ClickAction": ".click_action",
    "ClickActionData": ".click_action_data",
    "ClickContext": ".click_context",
    "CodeBlock": ".code_block",
    "CodeBlockParametersItem": ".code_block_parameters_item",
    "CodeBlockParametersItem_AwsSecret": ".code_block_parameters_item",
    "CodeBlockParametersItem_AzureSecret": ".code_block_parameters_item",
    "CodeBlockParametersItem_AzureVaultCredential": ".code_block_parameters_item",
    "CodeBlockParametersItem_BitwardenCreditCardData": ".code_block_parameters_item",
    "CodeBlockParametersItem_BitwardenLoginCredential": ".code_block_parameters_item",
    "CodeBlockParametersItem_BitwardenSensitiveInformation": ".code_block_parameters_item",
    "CodeBlockParametersItem_Context": ".code_block_parameters_item",
    "CodeBlockParametersItem_Credential": ".code_block_parameters_item",
    "CodeBlockParametersItem_Onepassword": ".code_block_parameters_item",
    "CodeBlockParametersItem_Output": ".code_block_parameters_item",
    "CodeBlockParametersItem_Workflow": ".code_block_parameters_item",
    "CodeBlockYaml": ".code_block_yaml",
    "ConditionalBlock": ".conditional_block",
    "ConditionalBlockYaml": ".conditional_block_yaml",
    "ContextParameter": ".context_parameter",
    "ContextParameterSource": ".context_parameter_source",
    "ContextParameterSource_AwsSecret": ".context_parameter_source",
    "ContextParameterSource_AzureSecret": ".context_parameter_source",
    "ContextParameterSource_AzureVaultCredential": ".context_parameter_source",
    "ContextParameterSource_BitwardenCreditCardData": ".context_parameter_source",
    "ContextParameterSource_BitwardenLoginCredential": ".context_parameter_source",
    "ContextParameterSource_BitwardenSensitiveInformation": ".context_parameter_source",
    "ContextParameterSource_Context": ".context_parameter_source",
    "ContextParameterSource_Credential": ".context_parameter_source",
    "ContextParameterSource_Onepassword": ".context_parameter_source",
    "ContextParameterSource_Output": ".context_parameter_source",
    "ContextParameterSource_Workflow": ".context_parameter_source",
    "ContextParameterValue": ".context_parameter_value",
    "ContextParameterYaml": ".context_parameter_yaml",
    "CreateCredentialRequest": ".create_credential_request",
    "CreateCredentialRequestCredential": ".create_credential_request_credential",
    "CreateScriptResponse": ".create_script_response",
    "CredentialParameter": ".credential_parameter",
    "CredentialParameterYaml": ".credential_parameter_yaml",
    "CredentialResponse": ".credential_response",
    "CredentialResponseCredential": ".credential_response_credential",
    "CredentialTypeOutput": ".credential_type_output",
    "CreditCardCredentialResponse": ".credit_card_credential_response",
    "DownloadToS3Block": ".download_to_s3block",
    "DownloadToS3BlockYaml": ".download_to_s3block_yaml",
    "Extensions": ".extensions",
    "ExtractAction": ".extract_action",
    "ExtractActionData": ".extract_action_data",
    "ExtractActionExtractSchema": ".extract_action_extract_schema",
    "ExtractionBlock": ".extraction_block",
    "ExtractionBlockDataSchema": ".extraction_block_data_schema",
    "ExtractionBlockParametersItem": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_AwsSecret": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_AzureSecret": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_AzureVaultCredential": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_BitwardenCreditCardData": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_BitwardenLoginCredential": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_BitwardenSensitiveInformation": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_Context": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_Credential": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_Onepassword": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_Output": ".extraction_block_parameters_item",
    "ExtractionBlockParametersItem_Workflow": ".extraction_block_parameters_item",
    "ExtractionBlockYaml": ".extraction_block_yaml",
    "ExtractionBlockYamlDataSchema": ".extraction_block_yaml_data_schema",
    "FileDownloadBlock": ".file_download_block",
    "FileDownloadBlockDataSchema": ".file_download_block_data_schema",
    "FileDownloadBlockParametersItem": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_AwsSecret": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_AzureSecret": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_AzureVaultCredential": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_BitwardenCreditCardData": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_BitwardenLoginCredential": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_BitwardenSensitiveInformation": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_Context": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_Credential": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_Onepassword": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_Output": ".file_download_block_parameters_item",
    "FileDownloadBlockParametersItem_Workflow": ".file_download_block_parameters_item",
    "FileDownloadBlockYaml": ".file_download_block_yaml",
    "FileEncoding": ".file_encoding",
    "FileInfo": ".file_info",
    "FileNode": ".file_node",
    "FileParserBlock": ".file_parser_block",
    "FileParserBlockYaml": ".file_parser_block_yaml",
    "FileStorageType": ".file_storage_type",
    "FileType": ".file_type",
    "FileUploadBlock": ".file_upload_block",
    "FileUploadBlockYaml": ".file_upload_block_yaml",
    "ForLoopBlock": ".for_loop_block",
    "ForLoopBlockDataSchema": ".for_loop_block_data_schema",
    "ForLoopBlockLoopBlocksItem": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Action": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Code": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Conditional": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_DownloadToS3": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Extraction": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_FileDownload": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_FileUpload": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_FileUrlParser": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_ForLoop": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_GotoUrl": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_HttpRequest": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_HumanInteraction": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Login": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Navigation": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_PdfParser": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_PrintPage": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_SendEmail": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Task": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_TaskV2": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_TextPrompt": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_UploadToS3": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Validation": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopBlocksItem_Wait": ".for_loop_block_loop_blocks_item",
    "ForLoopBlockLoopOver": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_AwsSecret": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_AzureSecret": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_AzureVaultCredential": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_BitwardenCreditCardData": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_BitwardenLoginCredential": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_BitwardenSensitiveInformation": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_Context": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_Credential": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_Onepassword": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_Output": ".for_loop_block_loop_over",
    "ForLoopBlockLoopOver_Workflow": ".for_loop_block_loop_over",
    "ForLoopBlockYaml": ".for_loop_block_yaml",
    "ForLoopBlockYamlDataSchema": ".for_loop_block_yaml_data_schema",
    "ForLoopBlockYamlLoopBlocksItem": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Action": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Code": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Conditional": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_DownloadToS3": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Extraction": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_FileDownload": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_FileUpload": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_FileUrlParser": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_ForLoop": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_GotoUrl": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_HttpRequest": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_HumanInteraction": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Login": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Navigation": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_PdfParser": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_PrintPage": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_SendEmail": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Task": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_TaskV2": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_TextPrompt": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_UploadToS3": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Validation": ".for_loop_block_yaml_loop_blocks_item",
    "ForLoopBlockYamlLoopBlocksItem_Wait": ".for_loop_block_yaml_loop_blocks_item",
    "GeoTarget": ".geo_target",
    "GetRunResponse": ".get_run_response",
    "GetRunResponse_AnthropicCua": ".get_run_response",
    "GetRunResponse_OpenaiCua": ".get_run_response",
    "GetRunResponse_TaskV1": ".get_run_response",
    "GetRunResponse_TaskV2": ".get_run_response",
    "GetRunResponse_UiTars": ".get_run_response",
    "GetRunResponse_WorkflowRun": ".get_run_response",
    "HttpRequestBlock": ".http_request_block",
    "HttpRequestBlockParametersItem": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_AwsSecret": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_AzureSecret": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_AzureVaultCredential": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_BitwardenCreditCardData": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_BitwardenLoginCredential": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_BitwardenSensitiveInformation": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_Context": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_Credential": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_Onepassword": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_Output": ".http_request_block_parameters_item",
    "HttpRequestBlockParametersItem_Workflow": ".http_request_block_parameters_item",
    "HttpRequestBlockYaml": ".http_request_block_yaml",
    "HttpValidationError": ".http_validation_error",
    "HumanInteractionBlock": ".human_interaction_block",
    "HumanInteractionBlockDataSchema": ".human_interaction_block_data_schema",
    "HumanInteractionBlockParametersItem": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_AwsSecret": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_AzureSecret": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_AzureVaultCredential": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_BitwardenCreditCardData": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_BitwardenLoginCredential": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_BitwardenSensitiveInformation": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_Context": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_Credential": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_Onepassword": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_Output": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockParametersItem_Workflow": ".human_interaction_block_parameters_item",
    "HumanInteractionBlockYaml": ".human_interaction_block_yaml",
    "InputOrSelectContext": ".input_or_select_context",
    "InputTextAction": ".input_text_action",
    "InputTextActionData": ".input_text_action_data",
    "JinjaBranchCriteria": ".jinja_branch_criteria",
    "LocateElementAction": ".locate_element_action",
    "LoginBlock": ".login_block",
    "LoginBlockDataSchema": ".login_block_data_schema",
    "LoginBlockParametersItem": ".login_block_parameters_item",
    "LoginBlockParametersItem_AwsSecret": ".login_block_parameters_item",
    "LoginBlockParametersItem_AzureSecret": ".login_block_parameters_item",
    "LoginBlockParametersItem_AzureVaultCredential": ".login_block_parameters_item",
    "LoginBlockParametersItem_BitwardenCreditCardData": ".login_block_parameters_item",
    "LoginBlockParametersItem_BitwardenLoginCredential": ".login_block_parameters_item",
    "LoginBlockParametersItem_BitwardenSensitiveInformation": ".login_block_parameters_item",
    "LoginBlockParametersItem_Context": ".login_block_parameters_item",
    "LoginBlockParametersItem_Credential": ".login_block_parameters_item",
    "LoginBlockParametersItem_Onepassword": ".login_block_parameters_item",
    "LoginBlockParametersItem_Output": ".login_block_parameters_item",
    "LoginBlockParametersItem_Workflow": ".login_block_parameters_item",
    "LoginBlockYaml": ".login_block_yaml",
    "NavigationBlock": ".navigation_block",
    "NavigationBlockDataSchema": ".navigation_block_data_schema",
    "NavigationBlockParametersItem": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_AwsSecret": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_AzureSecret": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_AzureVaultCredential": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_BitwardenCreditCardData": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_BitwardenLoginCredential": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_BitwardenSensitiveInformation": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_Context": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_Credential": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_Onepassword": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_Output": ".navigation_block_parameters_item",
    "NavigationBlockParametersItem_Workflow": ".navigation_block_parameters_item",
    "NavigationBlockYaml": ".navigation_block_yaml",
    "NonEmptyCreditCardCredential": ".non_empty_credit_card_credential",
    "NonEmptyPasswordCredential": ".non_empty_password_credential",
    "OnePasswordCredentialParameter": ".one_password_credential_parameter",
    "OnePasswordCredentialParameterYaml": ".one_password_credential_parameter_yaml",
    "OtpType": ".otp_type",
    "OutputParameter": ".output_parameter",
    "OutputParameterYaml": ".output_parameter_yaml",
    "PasswordCredentialResponse": ".password_credential_response",
    "PdfFormat": ".pdf_format",
    "PdfParserBlock": ".pdf_parser_block",
    "PdfParserBlockYaml": ".pdf_parser_block_yaml",
    "PersistentBrowserType": ".persistent_browser_type",
    "PlanTier": ".plan_tier",
    "PortalSessionResponse": ".portal_session_response",
    "PrintPageBlock": ".print_page_block",
    "PrintPageBlockParametersItem": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_AwsSecret": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_AzureSecret": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_AzureVaultCredential": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_BitwardenCreditCardData": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_BitwardenLoginCredential": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_BitwardenSensitiveInformation": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_Context": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_Credential": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_Onepassword": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_Output": ".print_page_block_parameters_item",
    "PrintPageBlockParametersItem_Workflow": ".print_page_block_parameters_item",
    "PrintPageBlockYaml": ".print_page_block_yaml",
    "PromptAction": ".prompt_action",
    "PromptBranchCriteria": ".prompt_branch_criteria",
    "ProxyLocation": ".proxy_location",
    "RetryRunWebhookRequest": ".retry_run_webhook_request",
    "RunEngine": ".run_engine",
    "RunSdkActionRequestAction": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_AiAct": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_AiClick": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_AiInputText": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_AiSelectOption": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_AiUploadFile": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_Extract": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_LocateElement": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_Prompt": ".run_sdk_action_request_action",
    "RunSdkActionRequestAction_Validate": ".run_sdk_action_request_action",
    "RunSdkActionResponse": ".run_sdk_action_response",
    "RunStatus": ".run_status",
    "Script": ".script",
    "ScriptFileCreate": ".script_file_create",
    "ScriptRunResponse": ".script_run_response",
    "SecretCredential": ".secret_credential",
    "SecretCredentialResponse": ".secret_credential_response",
    "SelectOption": ".select_option",
    "SelectOptionAction": ".select_option_action",
    "SelectOptionActionData": ".select_option_action_data",
    "SendEmailBlock": ".send_email_block",
    "SendEmailBlockYaml": ".send_email_block_yaml",
    "SkyvernForgeSdkSchemasCredentialsCredentialType": ".skyvern_forge_sdk_schemas_credentials_credential_type",
    "SkyvernSchemasRunBlocksCredentialType": ".skyvern_schemas_run_blocks_credential_type",
    "TaskBlock": ".task_block",
    "TaskBlockDataSchema": ".task_block_data_schema",
    "TaskBlockParametersItem": ".task_block_parameters_item",
    "TaskBlockParametersItem_AwsSecret": ".task_block_parameters_item",
    "TaskBlockParametersItem_AzureSecret": ".task_block_parameters_item",
    "TaskBlockParametersItem_AzureVaultCredential": ".task_block_parameters_item",
    "TaskBlockParametersItem_BitwardenCreditCardData": ".task_block_parameters_item",
    "TaskBlockParametersItem_BitwardenLoginCredential": ".task_block_parameters_item",
    "TaskBlockParametersItem_BitwardenSensitiveInformation": ".task_block_parameters_item",
    "TaskBlockParametersItem_Context": ".task_block_parameters_item",
    "TaskBlockParametersItem_Credential": ".task_block_parameters_item",
    "TaskBlockParametersItem_Onepassword": ".task_block_parameters_item",
    "TaskBlockParametersItem_Output": ".task_block_parameters_item",
    "TaskBlockParametersItem_Workflow": ".task_block_parameters_item",
    "TaskBlockYaml": ".task_block_yaml",
    "TaskBlockYamlDataSchema": ".task_block_yaml_data_schema",
    "TaskRunRequest": ".task_run_request",
    "TaskRunRequestDataExtractionSchema": ".task_run_request_data_extraction_schema",
    "TaskRunRequestProxyLocation": ".task_run_request_proxy_location",
    "TaskRunResponse": ".task_run_response",
    "TaskRunResponseOutput": ".task_run_response_output",
    "TaskV2Block": ".task_v2block",
    "TaskV2BlockYaml": ".task_v2block_yaml",
    "TextPromptBlock": ".text_prompt_block",
    "TextPromptBlockParametersItem": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_AwsSecret": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_AzureSecret": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_AzureVaultCredential": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_BitwardenCreditCardData": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_BitwardenLoginCredential": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_BitwardenSensitiveInformation": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_Context": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_Credential": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_Onepassword": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_Output": ".text_prompt_block_parameters_item",
    "TextPromptBlockParametersItem_Workflow": ".text_prompt_block_parameters_item",
    "TextPromptBlockYaml": ".text_prompt_block_yaml",
    "Thought": ".thought",
    "ThoughtScenario": ".thought_scenario",
    "ThoughtType": ".thought_type",
    "TotpCode": ".totp_code",
    "TotpType": ".totp_type",
    "UploadFileAction": ".upload_file_action",
    "UploadFileActionData": ".upload_file_action_data",
    "UploadFileResponse": ".upload_file_response",
    "UploadToS3Block": ".upload_to_s3block",
    "UploadToS3BlockYaml": ".upload_to_s3block_yaml",
    "UrlBlock": ".url_block",
    "UrlBlockDataSchema": ".url_block_data_schema",
    "UrlBlockParametersItem": ".url_block_parameters_item",
    "UrlBlockParametersItem_AwsSecret": ".url_block_parameters_item",
    "UrlBlockParametersItem_AzureSecret": ".url_block_parameters_item",
    "UrlBlockParametersItem_AzureVaultCredential": ".url_block_parameters_item",
    "UrlBlockParametersItem_BitwardenCreditCardData": ".url_block_parameters_item",
    "UrlBlockParametersItem_BitwardenLoginCredential": ".url_block_parameters_item",
    "UrlBlockParametersItem_BitwardenSensitiveInformation": ".url_block_parameters_item",
    "UrlBlockParametersItem_Context": ".url_block_parameters_item",
    "UrlBlockParametersItem_Credential": ".url_block_parameters_item",
    "UrlBlockParametersItem_Onepassword": ".url_block_parameters_item",
    "UrlBlockParametersItem_Output": ".url_block_parameters_item",
    "UrlBlockParametersItem_Workflow": ".url_block_parameters_item",
    "UrlBlockYaml": ".url_block_yaml",
    "UserDefinedError": ".user_defined_error",
    "ValidateAction": ".validate_action",
    "ValidationBlock": ".validation_block",
    "ValidationBlockDataSchema": ".validation_block_data_schema",
    "ValidationBlockParametersItem": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_AwsSecret": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_AzureSecret": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_AzureVaultCredential": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_BitwardenCreditCardData": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_BitwardenLoginCredential": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_BitwardenSensitiveInformation": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_Context": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_Credential": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_Onepassword": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_Output": ".validation_block_parameters_item",
    "ValidationBlockParametersItem_Workflow": ".validation_block_parameters_item",
    "ValidationBlockYaml": ".validation_block_yaml",
    "ValidationError": ".validation_error",
    "ValidationErrorLocItem": ".validation_error_loc_item",
    "WaitBlock": ".wait_block",
    "WaitBlockParametersItem": ".wait_block_parameters_item",
    "WaitBlockParametersItem_AwsSecret": ".wait_block_parameters_item",
    "WaitBlockParametersItem_AzureSecret": ".wait_block_parameters_item",
    "WaitBlockParametersItem_AzureVaultCredential": ".wait_block_parameters_item",
    "WaitBlockParametersItem_BitwardenCreditCardData": ".wait_block_parameters_item",
    "WaitBlockParametersItem_BitwardenLoginCredential": ".wait_block_parameters_item",
    "WaitBlockParametersItem_BitwardenSensitiveInformation": ".wait_block_parameters_item",
    "WaitBlockParametersItem_Context": ".wait_block_parameters_item",
    "WaitBlockParametersItem_Credential": ".wait_block_parameters_item",
    "WaitBlockParametersItem_Onepassword": ".wait_block_parameters_item",
    "WaitBlockParametersItem_Output": ".wait_block_parameters_item",
    "WaitBlockParametersItem_Workflow": ".wait_block_parameters_item",
    "WaitBlockYaml": ".wait_block_yaml",
    "Workflow": ".workflow",
    "WorkflowCreateYamlRequest": ".workflow_create_yaml_request",
    "WorkflowCreateYamlRequestProxyLocation": ".workflow_create_yaml_request_proxy_location",
    "WorkflowDefinition": ".workflow_definition",
    "WorkflowDefinitionBlocksItem": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Action": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Code": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Conditional": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_DownloadToS3": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Extraction": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_FileDownload": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_FileUpload": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_FileUrlParser": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_ForLoop": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_GotoUrl": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_HttpRequest": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_HumanInteraction": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Login": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Navigation": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_PdfParser": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_PrintPage": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_SendEmail": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Task": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_TaskV2": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_TextPrompt": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_UploadToS3": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Validation": ".workflow_definition_blocks_item",
    "WorkflowDefinitionBlocksItem_Wait": ".workflow_definition_blocks_item",
    "WorkflowDefinitionParametersItem": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_AwsSecret": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_AzureSecret": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_AzureVaultCredential": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_BitwardenCreditCardData": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_BitwardenLoginCredential": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_BitwardenSensitiveInformation": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_Context": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_Credential": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_Onepassword": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_Output": ".workflow_definition_parameters_item",
    "WorkflowDefinitionParametersItem_Workflow": ".workflow_definition_parameters_item",
    "WorkflowDefinitionYaml": ".workflow_definition_yaml",
    "WorkflowDefinitionYamlBlocksItem": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Action": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Code": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Conditional": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_DownloadToS3": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Extraction": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_FileDownload": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_FileUpload": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_FileUrlParser": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_ForLoop": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_GotoUrl": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_HttpRequest": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_HumanInteraction": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Login": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Navigation": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_PdfParser": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_PrintPage": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_SendEmail": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Task": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_TaskV2": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_TextPrompt": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_UploadToS3": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Validation": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlBlocksItem_Wait": ".workflow_definition_yaml_blocks_item",
    "WorkflowDefinitionYamlParametersItem": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_AwsSecret": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_AzureVaultCredential": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_BitwardenCreditCardData": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_BitwardenLoginCredential": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_BitwardenSensitiveInformation": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_Context": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_Credential": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_Onepassword": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_Output": ".workflow_definition_yaml_parameters_item",
    "WorkflowDefinitionYamlParametersItem_Workflow": ".workflow_definition_yaml_parameters_item",
    "WorkflowParameter": ".workflow_parameter",
    "WorkflowParameterDefaultValue": ".workflow_parameter_default_value",
    "WorkflowParameterType": ".workflow_parameter_type",
    "WorkflowParameterYaml": ".workflow_parameter_yaml",
    "WorkflowParameterYamlDefaultValue": ".workflow_parameter_yaml_default_value",
    "WorkflowProxyLocation": ".workflow_proxy_location",
    "WorkflowRequest": ".workflow_request",
    "WorkflowRun": ".workflow_run",
    "WorkflowRunBlock": ".workflow_run_block",
    "WorkflowRunBlockDataSchema": ".workflow_run_block_data_schema",
    "WorkflowRunBlockNavigationPayload": ".workflow_run_block_navigation_payload",
    "WorkflowRunBlockOutput": ".workflow_run_block_output",
    "WorkflowRunProxyLocation": ".workflow_run_proxy_location",
    "WorkflowRunRequest": ".workflow_run_request",
    "WorkflowRunRequestProxyLocation": ".workflow_run_request_proxy_location",
    "WorkflowRunResponse": ".workflow_run_response",
    "WorkflowRunResponseOutput": ".workflow_run_response_output",
    "WorkflowRunStatus": ".workflow_run_status",
    "WorkflowRunTimeline": ".workflow_run_timeline",
    "WorkflowRunTimelineType": ".workflow_run_timeline_type",
    "WorkflowStatus": ".workflow_status",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ActAction",
    "ActActionData",
    "Action",
    "ActionBlock",
    "ActionBlockDataSchema",
    "ActionBlockParametersItem",
    "ActionBlockParametersItem_AwsSecret",
    "ActionBlockParametersItem_AzureSecret",
    "ActionBlockParametersItem_AzureVaultCredential",
    "ActionBlockParametersItem_BitwardenCreditCardData",
    "ActionBlockParametersItem_BitwardenLoginCredential",
    "ActionBlockParametersItem_BitwardenSensitiveInformation",
    "ActionBlockParametersItem_Context",
    "ActionBlockParametersItem_Credential",
    "ActionBlockParametersItem_Onepassword",
    "ActionBlockParametersItem_Output",
    "ActionBlockParametersItem_Workflow",
    "ActionBlockYaml",
    "ActionStatus",
    "ActionType",
    "Artifact",
    "ArtifactType",
    "AwsSecretParameter",
    "AwsSecretParameterYaml",
    "AzureSecretParameter",
    "AzureVaultCredentialParameter",
    "AzureVaultCredentialParameterYaml",
    "BillingStateResponse",
    "BitwardenCreditCardDataParameter",
    "BitwardenCreditCardDataParameterYaml",
    "BitwardenLoginCredentialParameter",
    "BitwardenLoginCredentialParameterYaml",
    "BitwardenSensitiveInformationParameter",
    "BitwardenSensitiveInformationParameterYaml",
    "BlockType",
    "BranchCondition",
    "BranchConditionCriteria",
    "BranchConditionCriteria_Jinja2Template",
    "BranchConditionCriteria_Prompt",
    "BranchConditionYaml",
    "BranchCriteriaYaml",
    "BranchCriteriaYamlCriteriaType",
    "BrowserProfile",
    "BrowserSessionResponse",
    "ChangeTierResponse",
    "CheckoutSessionResponse",
    "ClearCacheResponse",
    "ClickAction",
    "ClickActionData",
    "ClickContext",
    "CodeBlock",
    "CodeBlockParametersItem",
    "CodeBlockParametersItem_AwsSecret",
    "CodeBlockParametersItem_AzureSecret",
    "CodeBlockParametersItem_AzureVaultCredential",
    "CodeBlockParametersItem_BitwardenCreditCardData",
    "CodeBlockParametersItem_BitwardenLoginCredential",
    "CodeBlockParametersItem_BitwardenSensitiveInformation",
    "CodeBlockParametersItem_Context",
    "CodeBlockParametersItem_Credential",
    "CodeBlockParametersItem_Onepassword",
    "CodeBlockParametersItem_Output",
    "CodeBlockParametersItem_Workflow",
    "CodeBlockYaml",
    "ConditionalBlock",
    "ConditionalBlockYaml",
    "ContextParameter",
    "ContextParameterSource",
    "ContextParameterSource_AwsSecret",
    "ContextParameterSource_AzureSecret",
    "ContextParameterSource_AzureVaultCredential",
    "ContextParameterSource_BitwardenCreditCardData",
    "ContextParameterSource_BitwardenLoginCredential",
    "ContextParameterSource_BitwardenSensitiveInformation",
    "ContextParameterSource_Context",
    "ContextParameterSource_Credential",
    "ContextParameterSource_Onepassword",
    "ContextParameterSource_Output",
    "ContextParameterSource_Workflow",
    "ContextParameterValue",
    "ContextParameterYaml",
    "CreateCredentialRequest",
    "CreateCredentialRequestCredential",
    "CreateScriptResponse",
    "CredentialParameter",
    "CredentialParameterYaml",
    "CredentialResponse",
    "CredentialResponseCredential",
    "CredentialTypeOutput",
    "CreditCardCredentialResponse",
    "DownloadToS3Block",
    "DownloadToS3BlockYaml",
    "Extensions",
    "ExtractAction",
    "ExtractActionData",
    "ExtractActionExtractSchema",
    "ExtractionBlock",
    "ExtractionBlockDataSchema",
    "ExtractionBlockParametersItem",
    "ExtractionBlockParametersItem_AwsSecret",
    "ExtractionBlockParametersItem_AzureSecret",
    "ExtractionBlockParametersItem_AzureVaultCredential",
    "ExtractionBlockParametersItem_BitwardenCreditCardData",
    "ExtractionBlockParametersItem_BitwardenLoginCredential",
    "ExtractionBlockParametersItem_BitwardenSensitiveInformation",
    "ExtractionBlockParametersItem_Context",
    "ExtractionBlockParametersItem_Credential",
    "ExtractionBlockParametersItem_Onepassword",
    "ExtractionBlockParametersItem_Output",
    "ExtractionBlockParametersItem_Workflow",
    "ExtractionBlockYaml",
    "ExtractionBlockYamlDataSchema",
    "FileDownloadBlock",
    "FileDownloadBlockDataSchema",
    "FileDownloadBlockParametersItem",
    "FileDownloadBlockParametersItem_AwsSecret",
    "FileDownloadBlockParametersItem_AzureSecret",
    "FileDownloadBlockParametersItem_AzureVaultCredential",
    "FileDownloadBlockParametersItem_BitwardenCreditCardData",
    "FileDownloadBlockParametersItem_BitwardenLoginCredential",
    "FileDownloadBlockParametersItem_BitwardenSensitiveInformation",
    "FileDownloadBlockParametersItem_Context",
    "FileDownloadBlockParametersItem_Credential",
    "FileDownloadBlockParametersItem_Onepassword",
    "FileDownloadBlockParametersItem_Output",
    "FileDownloadBlockParametersItem_Workflow",
    "FileDownloadBlockYaml",
    "FileEncoding",
    "FileInfo",
    "FileNode",
    "FileParserBlock",
    "FileParserBlockYaml",
    "FileStorageType",
    "FileType",
    "FileUploadBlock",
    "FileUploadBlockYaml",
    "ForLoopBlock",
    "ForLoopBlockDataSchema",
    "ForLoopBlockLoopBlocksItem",
    "ForLoopBlockLoopBlocksItem_Action",
    "ForLoopBlockLoopBlocksItem_Code",
    "ForLoopBlockLoopBlocksItem_Conditional",
    "ForLoopBlockLoopBlocksItem_DownloadToS3",
    "ForLoopBlockLoopBlocksItem_Extraction",
    "ForLoopBlockLoopBlocksItem_FileDownload",
    "ForLoopBlockLoopBlocksItem_FileUpload",
    "ForLoopBlockLoopBlocksItem_FileUrlParser",
    "ForLoopBlockLoopBlocksItem_ForLoop",
    "ForLoopBlockLoopBlocksItem_GotoUrl",
    "ForLoopBlockLoopBlocksItem_HttpRequest",
    "ForLoopBlockLoopBlocksItem_HumanInteraction",
    "ForLoopBlockLoopBlocksItem_Login",
    "ForLoopBlockLoopBlocksItem_Navigation",
    "ForLoopBlockLoopBlocksItem_PdfParser",
    "ForLoopBlockLoopBlocksItem_PrintPage",
    "ForLoopBlockLoopBlocksItem_SendEmail",
    "ForLoopBlockLoopBlocksItem_Task",
    "ForLoopBlockLoopBlocksItem_TaskV2",
    "ForLoopBlockLoopBlocksItem_TextPrompt",
    "ForLoopBlockLoopBlocksItem_UploadToS3",
    "ForLoopBlockLoopBlocksItem_Validation",
    "ForLoopBlockLoopBlocksItem_Wait",
    "ForLoopBlockLoopOver",
    "ForLoopBlockLoopOver_AwsSecret",
    "ForLoopBlockLoopOver_AzureSecret",
    "ForLoopBlockLoopOver_AzureVaultCredential",
    "ForLoopBlockLoopOver_BitwardenCreditCardData",
    "ForLoopBlockLoopOver_BitwardenLoginCredential",
    "ForLoopBlockLoopOver_BitwardenSensitiveInformation",
    "ForLoopBlockLoopOver_Context",
    "ForLoopBlockLoopOver_Credential",
    "ForLoopBlockLoopOver_Onepassword",
    "ForLoopBlockLoopOver_Output",
    "ForLoopBlockLoopOver_Workflow",
    "ForLoopBlockYaml",
    "ForLoopBlockYamlDataSchema",
    "ForLoopBlockYamlLoopBlocksItem",
    "ForLoopBlockYamlLoopBlocksItem_Action",
    "ForLoopBlockYamlLoopBlocksItem_Code",
    "ForLoopBlockYamlLoopBlocksItem_Conditional",
    "ForLoopBlockYamlLoopBlocksItem_DownloadToS3",
    "ForLoopBlockYamlLoopBlocksItem_Extraction",
    "ForLoopBlockYamlLoopBlocksItem_FileDownload",
    "ForLoopBlockYamlLoopBlocksItem_FileUpload",
    "ForLoopBlockYamlLoopBlocksItem_FileUrlParser",
    "ForLoopBlockYamlLoopBlocksItem_ForLoop",
    "ForLoopBlockYamlLoopBlocksItem_GotoUrl",
    "ForLoopBlockYamlLoopBlocksItem_HttpRequest",
    "ForLoopBlockYamlLoopBlocksItem_HumanInteraction",
    "ForLoopBlockYamlLoopBlocksItem_Login",
    "ForLoopBlockYamlLoopBlocksItem_Navigation",
    "ForLoopBlockYamlLoopBlocksItem_PdfParser",
    "ForLoopBlockYamlLoopBlocksItem_PrintPage",
    "ForLoopBlockYamlLoopBlocksItem_SendEmail",
    "ForLoopBlockYamlLoopBlocksItem_Task",
    "ForLoopBlockYamlLoopBlocksItem_TaskV2",
    "ForLoopBlockYamlLoopBlocksItem_TextPrompt",
    "ForLoopBlockYamlLoopBlocksItem_UploadToS3",
    "ForLoopBlockYamlLoopBlocksItem_Validation",
    "ForLoopBlockYamlLoopBlocksItem_Wait",
    "GeoTarget",
    "GetRunResponse",
    "GetRunResponse_AnthropicCua",
    "GetRunResponse_OpenaiCua",
    "GetRunResponse_TaskV1",
    "GetRunResponse_TaskV2",
    "GetRunResponse_UiTars",
    "GetRunResponse_WorkflowRun",
    "HttpRequestBlock",
    "HttpRequestBlockParametersItem",
    "HttpRequestBlockParametersItem_AwsSecret",
    "HttpRequestBlockParametersItem_AzureSecret",
    "HttpRequestBlockParametersItem_AzureVaultCredential",
    "HttpRequestBlockParametersItem_BitwardenCreditCardData",
    "HttpRequestBlockParametersItem_BitwardenLoginCredential",
    "HttpRequestBlockParametersItem_BitwardenSensitiveInformation",
    "HttpRequestBlockParametersItem_Context",
    "HttpRequestBlockParametersItem_Credential",
    "HttpRequestBlockParametersItem_Onepassword",
    "HttpRequestBlockParametersItem_Output",
    "HttpRequestBlockParametersItem_Workflow",
    "HttpRequestBlockYaml",
    "HttpValidationError",
    "HumanInteractionBlock",
    "HumanInteractionBlockDataSchema",
    "HumanInteractionBlockParametersItem",
    "HumanInteractionBlockParametersItem_AwsSecret",
    "HumanInteractionBlockParametersItem_AzureSecret",
    "HumanInteractionBlockParametersItem_AzureVaultCredential",
    "HumanInteractionBlockParametersItem_BitwardenCreditCardData",
    "HumanInteractionBlockParametersItem_BitwardenLoginCredential",
    "HumanInteractionBlockParametersItem_BitwardenSensitiveInformation",
    "HumanInteractionBlockParametersItem_Context",
    "HumanInteractionBlockParametersItem_Credential",
    "HumanInteractionBlockParametersItem_Onepassword",
    "HumanInteractionBlockParametersItem_Output",
    "HumanInteractionBlockParametersItem_Workflow",
    "HumanInteractionBlockYaml",
    "InputOrSelectContext",
    "InputTextAction",
    "InputTextActionData",
    "JinjaBranchCriteria",
    "LocateElementAction",
    "LoginBlock",
    "LoginBlockDataSchema",
    "LoginBlockParametersItem",
    "LoginBlockParametersItem_AwsSecret",
    "LoginBlockParametersItem_AzureSecret",
    "LoginBlockParametersItem_AzureVaultCredential",
    "LoginBlockParametersItem_BitwardenCreditCardData",
    "LoginBlockParametersItem_BitwardenLoginCredential",
    "LoginBlockParametersItem_BitwardenSensitiveInformation",
    "LoginBlockParametersItem_Context",
    "LoginBlockParametersItem_Credential",
    "LoginBlockParametersItem_Onepassword",
    "LoginBlockParametersItem_Output",
    "LoginBlockParametersItem_Workflow",
    "LoginBlockYaml",
    "NavigationBlock",
    "NavigationBlockDataSchema",
    "NavigationBlockParametersItem",
    "NavigationBlockParametersItem_AwsSecret",
    "NavigationBlockParametersItem_AzureSecret",
    "NavigationBlockParametersItem_AzureVaultCredential",
    "NavigationBlockParametersItem_BitwardenCreditCardData",
    "NavigationBlockParametersItem_BitwardenLoginCredential",
    "NavigationBlockParametersItem_BitwardenSensitiveInformation",
    "NavigationBlockParametersItem_Context",
    "NavigationBlockParametersItem_Credential",
    "NavigationBlockParametersItem_Onepassword",
    "NavigationBlockParametersItem_Output",
    "NavigationBlockParametersItem_Workflow",
    "NavigationBlockYaml",
    "NonEmptyCreditCardCredential",
    "NonEmptyPasswordCredential",
    "OnePasswordCredentialParameter",
    "OnePasswordCredentialParameterYaml",
    "OtpType",
    "OutputParameter",
    "OutputParameterYaml",
    "PasswordCredentialResponse",
    "PdfFormat",
    "PdfParserBlock",
    "PdfParserBlockYaml",
    "PersistentBrowserType",
    "PlanTier",
    "PortalSessionResponse",
    "PrintPageBlock",
    "PrintPageBlockParametersItem",
    "PrintPageBlockParametersItem_AwsSecret",
    "PrintPageBlockParametersItem_AzureSecret",
    "PrintPageBlockParametersItem_AzureVaultCredential",
    "PrintPageBlockParametersItem_BitwardenCreditCardData",
    "PrintPageBlockParametersItem_BitwardenLoginCredential",
    "PrintPageBlockParametersItem_BitwardenSensitiveInformation",
    "PrintPageBlockParametersItem_Context",
    "PrintPageBlockParametersItem_Credential",
    "PrintPageBlockParametersItem_Onepassword",
    "PrintPageBlockParametersItem_Output",
    "PrintPageBlockParametersItem_Workflow",
    "PrintPageBlockYaml",
    "PromptAction",
    "PromptBranchCriteria",
    "ProxyLocation",
    "RetryRunWebhookRequest",
    "RunEngine",
    "RunSdkActionRequestAction",
    "RunSdkActionRequestAction_AiAct",
    "RunSdkActionRequestAction_AiClick",
    "RunSdkActionRequestAction_AiInputText",
    "RunSdkActionRequestAction_AiSelectOption",
    "RunSdkActionRequestAction_AiUploadFile",
    "RunSdkActionRequestAction_Extract",
    "RunSdkActionRequestAction_LocateElement",
    "RunSdkActionRequestAction_Prompt",
    "RunSdkActionRequestAction_Validate",
    "RunSdkActionResponse",
    "RunStatus",
    "Script",
    "ScriptFileCreate",
    "ScriptRunResponse",
    "SecretCredential",
    "SecretCredentialResponse",
    "SelectOption",
    "SelectOptionAction",
    "SelectOptionActionData",
    "SendEmailBlock",
    "SendEmailBlockYaml",
    "SkyvernForgeSdkSchemasCredentialsCredentialType",
    "SkyvernSchemasRunBlocksCredentialType",
    "TaskBlock",
    "TaskBlockDataSchema",
    "TaskBlockParametersItem",
    "TaskBlockParametersItem_AwsSecret",
    "TaskBlockParametersItem_AzureSecret",
    "TaskBlockParametersItem_AzureVaultCredential",
    "TaskBlockParametersItem_BitwardenCreditCardData",
    "TaskBlockParametersItem_BitwardenLoginCredential",
    "TaskBlockParametersItem_BitwardenSensitiveInformation",
    "TaskBlockParametersItem_Context",
    "TaskBlockParametersItem_Credential",
    "TaskBlockParametersItem_Onepassword",
    "TaskBlockParametersItem_Output",
    "TaskBlockParametersItem_Workflow",
    "TaskBlockYaml",
    "TaskBlockYamlDataSchema",
    "TaskRunRequest",
    "TaskRunRequestDataExtractionSchema",
    "TaskRunRequestProxyLocation",
    "TaskRunResponse",
    "TaskRunResponseOutput",
    "TaskV2Block",
    "TaskV2BlockYaml",
    "TextPromptBlock",
    "TextPromptBlockParametersItem",
    "TextPromptBlockParametersItem_AwsSecret",
    "TextPromptBlockParametersItem_AzureSecret",
    "TextPromptBlockParametersItem_AzureVaultCredential",
    "TextPromptBlockParametersItem_BitwardenCreditCardData",
    "TextPromptBlockParametersItem_BitwardenLoginCredential",
    "TextPromptBlockParametersItem_BitwardenSensitiveInformation",
    "TextPromptBlockParametersItem_Context",
    "TextPromptBlockParametersItem_Credential",
    "TextPromptBlockParametersItem_Onepassword",
    "TextPromptBlockParametersItem_Output",
    "TextPromptBlockParametersItem_Workflow",
    "TextPromptBlockYaml",
    "Thought",
    "ThoughtScenario",
    "ThoughtType",
    "TotpCode",
    "TotpType",
    "UploadFileAction",
    "UploadFileActionData",
    "UploadFileResponse",
    "UploadToS3Block",
    "UploadToS3BlockYaml",
    "UrlBlock",
    "UrlBlockDataSchema",
    "UrlBlockParametersItem",
    "UrlBlockParametersItem_AwsSecret",
    "UrlBlockParametersItem_AzureSecret",
    "UrlBlockParametersItem_AzureVaultCredential",
    "UrlBlockParametersItem_BitwardenCreditCardData",
    "UrlBlockParametersItem_BitwardenLoginCredential",
    "UrlBlockParametersItem_BitwardenSensitiveInformation",
    "UrlBlockParametersItem_Context",
    "UrlBlockParametersItem_Credential",
    "UrlBlockParametersItem_Onepassword",
    "UrlBlockParametersItem_Output",
    "UrlBlockParametersItem_Workflow",
    "UrlBlockYaml",
    "UserDefinedError",
    "ValidateAction",
    "ValidationBlock",
    "ValidationBlockDataSchema",
    "ValidationBlockParametersItem",
    "ValidationBlockParametersItem_AwsSecret",
    "ValidationBlockParametersItem_AzureSecret",
    "ValidationBlockParametersItem_AzureVaultCredential",
    "ValidationBlockParametersItem_BitwardenCreditCardData",
    "ValidationBlockParametersItem_BitwardenLoginCredential",
    "ValidationBlockParametersItem_BitwardenSensitiveInformation",
    "ValidationBlockParametersItem_Context",
    "ValidationBlockParametersItem_Credential",
    "ValidationBlockParametersItem_Onepassword",
    "ValidationBlockParametersItem_Output",
    "ValidationBlockParametersItem_Workflow",
    "ValidationBlockYaml",
    "ValidationError",
    "ValidationErrorLocItem",
    "WaitBlock",
    "WaitBlockParametersItem",
    "WaitBlockParametersItem_AwsSecret",
    "WaitBlockParametersItem_AzureSecret",
    "WaitBlockParametersItem_AzureVaultCredential",
    "WaitBlockParametersItem_BitwardenCreditCardData",
    "WaitBlockParametersItem_BitwardenLoginCredential",
    "WaitBlockParametersItem_BitwardenSensitiveInformation",
    "WaitBlockParametersItem_Context",
    "WaitBlockParametersItem_Credential",
    "WaitBlockParametersItem_Onepassword",
    "WaitBlockParametersItem_Output",
    "WaitBlockParametersItem_Workflow",
    "WaitBlockYaml",
    "Workflow",
    "WorkflowCreateYamlRequest",
    "WorkflowCreateYamlRequestProxyLocation",
    "WorkflowDefinition",
    "WorkflowDefinitionBlocksItem",
    "WorkflowDefinitionBlocksItem_Action",
    "WorkflowDefinitionBlocksItem_Code",
    "WorkflowDefinitionBlocksItem_Conditional",
    "WorkflowDefinitionBlocksItem_DownloadToS3",
    "WorkflowDefinitionBlocksItem_Extraction",
    "WorkflowDefinitionBlocksItem_FileDownload",
    "WorkflowDefinitionBlocksItem_FileUpload",
    "WorkflowDefinitionBlocksItem_FileUrlParser",
    "WorkflowDefinitionBlocksItem_ForLoop",
    "WorkflowDefinitionBlocksItem_GotoUrl",
    "WorkflowDefinitionBlocksItem_HttpRequest",
    "WorkflowDefinitionBlocksItem_HumanInteraction",
    "WorkflowDefinitionBlocksItem_Login",
    "WorkflowDefinitionBlocksItem_Navigation",
    "WorkflowDefinitionBlocksItem_PdfParser",
    "WorkflowDefinitionBlocksItem_PrintPage",
    "WorkflowDefinitionBlocksItem_SendEmail",
    "WorkflowDefinitionBlocksItem_Task",
    "WorkflowDefinitionBlocksItem_TaskV2",
    "WorkflowDefinitionBlocksItem_TextPrompt",
    "WorkflowDefinitionBlocksItem_UploadToS3",
    "WorkflowDefinitionBlocksItem_Validation",
    "WorkflowDefinitionBlocksItem_Wait",
    "WorkflowDefinitionParametersItem",
    "WorkflowDefinitionParametersItem_AwsSecret",
    "WorkflowDefinitionParametersItem_AzureSecret",
    "WorkflowDefinitionParametersItem_AzureVaultCredential",
    "WorkflowDefinitionParametersItem_BitwardenCreditCardData",
    "WorkflowDefinitionParametersItem_BitwardenLoginCredential",
    "WorkflowDefinitionParametersItem_BitwardenSensitiveInformation",
    "WorkflowDefinitionParametersItem_Context",
    "WorkflowDefinitionParametersItem_Credential",
    "WorkflowDefinitionParametersItem_Onepassword",
    "WorkflowDefinitionParametersItem_Output",
    "WorkflowDefinitionParametersItem_Workflow",
    "WorkflowDefinitionYaml",
    "WorkflowDefinitionYamlBlocksItem",
    "WorkflowDefinitionYamlBlocksItem_Action",
    "WorkflowDefinitionYamlBlocksItem_Code",
    "WorkflowDefinitionYamlBlocksItem_Conditional",
    "WorkflowDefinitionYamlBlocksItem_DownloadToS3",
    "WorkflowDefinitionYamlBlocksItem_Extraction",
    "WorkflowDefinitionYamlBlocksItem_FileDownload",
    "WorkflowDefinitionYamlBlocksItem_FileUpload",
    "WorkflowDefinitionYamlBlocksItem_FileUrlParser",
    "WorkflowDefinitionYamlBlocksItem_ForLoop",
    "WorkflowDefinitionYamlBlocksItem_GotoUrl",
    "WorkflowDefinitionYamlBlocksItem_HttpRequest",
    "WorkflowDefinitionYamlBlocksItem_HumanInteraction",
    "WorkflowDefinitionYamlBlocksItem_Login",
    "WorkflowDefinitionYamlBlocksItem_Navigation",
    "WorkflowDefinitionYamlBlocksItem_PdfParser",
    "WorkflowDefinitionYamlBlocksItem_PrintPage",
    "WorkflowDefinitionYamlBlocksItem_SendEmail",
    "WorkflowDefinitionYamlBlocksItem_Task",
    "WorkflowDefinitionYamlBlocksItem_TaskV2",
    "WorkflowDefinitionYamlBlocksItem_TextPrompt",
    "WorkflowDefinitionYamlBlocksItem_UploadToS3",
    "WorkflowDefinitionYamlBlocksItem_Validation",
    "WorkflowDefinitionYamlBlocksItem_Wait",
    "WorkflowDefinitionYamlParametersItem",
    "WorkflowDefinitionYamlParametersItem_AwsSecret",
    "WorkflowDefinitionYamlParametersItem_AzureVaultCredential",
    "WorkflowDefinitionYamlParametersItem_BitwardenCreditCardData",
    "WorkflowDefinitionYamlParametersItem_BitwardenLoginCredential",
    "WorkflowDefinitionYamlParametersItem_BitwardenSensitiveInformation",
    "WorkflowDefinitionYamlParametersItem_Context",
    "WorkflowDefinitionYamlParametersItem_Credential",
    "WorkflowDefinitionYamlParametersItem_Onepassword",
    "WorkflowDefinitionYamlParametersItem_Output",
    "WorkflowDefinitionYamlParametersItem_Workflow",
    "WorkflowParameter",
    "WorkflowParameterDefaultValue",
    "WorkflowParameterType",
    "WorkflowParameterYaml",
    "WorkflowParameterYamlDefaultValue",
    "WorkflowProxyLocation",
    "WorkflowRequest",
    "WorkflowRun",
    "WorkflowRunBlock",
    "WorkflowRunBlockDataSchema",
    "WorkflowRunBlockNavigationPayload",
    "WorkflowRunBlockOutput",
    "WorkflowRunProxyLocation",
    "WorkflowRunRequest",
    "WorkflowRunRequestProxyLocation",
    "WorkflowRunResponse",
    "WorkflowRunResponseOutput",
    "WorkflowRunStatus",
    "WorkflowRunTimeline",
    "WorkflowRunTimelineType",
    "WorkflowStatus",
]



from enum import StrEnum


class OrganizationAuthTokenType(StrEnum):
    api = "api"
    mcp_admin_impersonation = "mcp_admin_impersonation"
    onepassword_service_account = "onepassword_service_account"
    azure_client_secret_credential = "azure_client_secret_credential"
    custom_credential_service = "custom_credential_service"


class TaskType(StrEnum):
    general = "general"
    validation = "validation"
    action = "action"



"""In-process notification registry using asyncio queues (single-pod only)."""

import asyncio
from collections import defaultdict

import structlog

from skyvern.forge.sdk.notification.base import BaseNotificationRegistry

LOG = structlog.get_logger()


class LocalNotificationRegistry(BaseNotificationRegistry):
    """In-process fan-out pub/sub using asyncio queues. Single-pod only."""

    def __init__(self) -> None:
        self._subscribers: dict[str, list[asyncio.Queue[dict]]] = defaultdict(list)

    def subscribe(self, organization_id: str) -> asyncio.Queue[dict]:
        queue: asyncio.Queue[dict] = asyncio.Queue()
        self._subscribers[organization_id].append(queue)
        LOG.info("Notification subscriber added", organization_id=organization_id)
        return queue

    def unsubscribe(self, organization_id: str, queue: asyncio.Queue[dict]) -> None:
        queues = self._subscribers.get(organization_id)
        if queues:
            try:
                queues.remove(queue)
            except ValueError:
                pass
            if not queues:
                del self._subscribers[organization_id]
        LOG.info("Notification subscriber removed", organization_id=organization_id)

    def publish(self, organization_id: str, message: dict) -> None:
        queues = self._subscribers.get(organization_id, [])
        for queue in queues:
            try:
                queue.put_nowait(message)
            except asyncio.QueueFull:
                LOG.warning(
                    "Notification queue full, dropping message",
                    organization_id=organization_id,
                )



import asyncio
import os
import pathlib
import tempfile
from typing import Any

import httpx
import structlog
from dotenv import load_dotenv
from playwright.async_api import Playwright, async_playwright

from skyvern.client import AsyncSkyvern, BrowserSessionResponse, SkyvernEnvironment
from skyvern.client.core import RequestOptions
from skyvern.client.types.task_run_response import TaskRunResponse
from skyvern.client.types.workflow_run_response import WorkflowRunResponse
from skyvern.forge.sdk.api.llm.models import LLMConfig, LLMRouterConfig
from skyvern.library.constants import DEFAULT_AGENT_HEARTBEAT_INTERVAL, DEFAULT_AGENT_TIMEOUT, DEFAULT_CDP_PORT
from skyvern.library.skyvern_browser import SkyvernBrowser
from skyvern.schemas.run_blocks import CredentialType
from skyvern.schemas.runs import ProxyLocation, RunEngine, RunStatus

LOG = structlog.get_logger()


def _get_browser_session_url(browser_session_id: str) -> str:
    return f"https://app.skyvern.com/browser-session/{browser_session_id}"


class Skyvern(AsyncSkyvern):
    """Main entry point for the Skyvern SDK.

    This class provides methods to launch and connect to browsers (both local and cloud-hosted),
    and access the Skyvern API client for task and workflow management. It combines browser
    automation capabilities with AI-powered task execution.

    Example:
        ```python

        # Remote mode: Connect to Skyvern Cloud (API key required)
        skyvern = Skyvern(api_key="your-api-key")

        # Local/embedded mode (run `skyvern quickstart` first):
        skyvern = Skyvern.local()

        # Launch a local browser (works only in local environment)
        browser = await skyvern.launch_local_browser(headless=False)
        page = await browser.get_working_page()

        # Or use a cloud browser (works only in cloud environment)
        browser = await skyvern.use_cloud_browser()
        page = await browser.get_working_page()

        # Execute AI-powered tasks
        await page.agent.run_task("Fill out the form and submit it")
        ```

    You can also mix AI-powered tasks with direct browser control in the same session:
        ```python

        # Create credentials via API
        credential = await skyvern.create_credential(
            name="my_user",
            credential_type="password",
            credential=NonEmptyPasswordCredential(username="user@example.com", password="my_password"),
        )

        # Get a browser page
        browser = await skyvern.launch_cloud_browser()
        page = await browser.get_working_page()

        # Navigate manually
        await page.goto("https://example.com")

        # Use AI to handle login
        await page.agent.login(
            credential_type=CredentialType.skyvern,
            credential_id=credential.credential_id,
        )

        # Continue with manual browser control
        await page.click("#invoices-button")
        await page.fill("#search", "my invoice")
        await page.screenshot(path="screenshot.png", full_page=True)
        ```
    """

    def __init__(
        self,
        *,
        api_key: str,
        environment: SkyvernEnvironment = SkyvernEnvironment.CLOUD,
        base_url: str | None = None,
        timeout: float | None = None,
        follow_redirects: bool | None = True,
        httpx_client: httpx.AsyncClient | None = None,
    ) -> None:
        """Remote mode: Connect to Skyvern Cloud or self-hosted instance.

        Args:
            api_key: API key for authenticating with Skyvern.
                Can be found on the settings page: https://app.skyvern.com/settings
            environment: The Skyvern environment to connect to. Use SkyvernEnvironment.CLOUD
                for Skyvern Cloud or SkyvernEnvironment.PRODUCTION/STAGING for self-hosted
                instances. Defaults to SkyvernEnvironment.CLOUD.
            base_url: Override the base URL for the Skyvern API. If not provided, uses the default URL for
                the specified environment.
            timeout: Timeout in seconds for API requests. If not provided, uses the default timeout.
            follow_redirects: Whether to automatically follow HTTP redirects. Defaults to True.
            httpx_client: Custom httpx AsyncClient for making API requests.
                If not provided, a default client will be created.
        """
        super().__init__(
            base_url=base_url,
            environment=environment,
            api_key=api_key,
            timeout=timeout,
            follow_redirects=follow_redirects,
            httpx_client=httpx_client,
        )

        self._environment = environment
        self._api_key: str | None = api_key
        self._playwright: Playwright | None = None

    @classmethod
    def local(
        cls,
        *,
        llm_config: LLMRouterConfig | LLMConfig | None = None,
        settings: dict[str, Any] | None = None,
    ) -> "Skyvern":
        """Local/embedded mode: Run Skyvern locally in-process.

        Prerequisites:
            Run `skyvern quickstart` first to set up your local environment and create a .env file

        Args:
            llm_config: Optional custom LLM configuration (LLMConfig or LLMRouterConfig).
                If provided, this will be registered as "CUSTOM_LLM" and used as the primary LLM,
                overriding the LLM_KEY setting from your .env file.
                If not provided, uses the LLM configured via LLM_KEY in your .env file.

                Example 1 - Using .env configuration (simplest, recommended):
                    ```python
                    from skyvern import Skyvern

                    # Uses LLM_KEY and other settings from your .env file
                    # Created by running `skyvern quickstart`
                    skyvern = Skyvern.local()
                    ```

                Example 2 - Custom LLM with environment variables:
                    ```python
                    from skyvern import Skyvern
                    from skyvern.forge.sdk.api.llm.models import LLMConfig

                    # Assumes OPENAI_API_KEY is set in your environment
                    skyvern = Skyvern.local(
                        llm_config=LLMConfig(
                            model_name="gpt-4o",
                            required_env_vars=["OPENAI_API_KEY"],
                            supports_vision=True,
                            add_assistant_prefix=False,
                        )
                    )
                    ```

                Example 3 - Explicitly providing credentials:
                    ```python
                    from skyvern import Skyvern
                    from skyvern.forge.sdk.api.llm.models import LLMConfig, LiteLLMParams

                    skyvern = Skyvern.local(
                        llm_config=LLMConfig(
                            model_name="gpt-4o",
                            required_env_vars=[],  # No env vars required
                            supports_vision=True,
                            add_assistant_prefix=False,
                            litellm_params=LiteLLMParams(
                                api_base="https://api.openai.com/v1",
                                api_key="sk-...",  # Your API key
                            ),
                        )
                    )
                    ```
            settings: Optional dictionary of Skyvern settings to override.
                These override the corresponding settings from your .env file.
                Example: {"MAX_STEPS_PER_RUN": 100, "BROWSER_TYPE": "chromium-headful"}

        Returns:
            Skyvern: A Skyvern instance running in local/embedded mode.
        """
        from skyvern.library.embedded_server_factory import create_embedded_server  # noqa: PLC0415

        if not os.path.exists(".env"):
            raise ValueError("Please run `skyvern quickstart` to set up your local Skyvern environment")

        load_dotenv(".env")
        api_key = os.getenv("SKYVERN_API_KEY")
        if not api_key:
            raise ValueError("SKYVERN_API_KEY is not set. Provide api_key or set SKYVERN_API_KEY in .env file.")

        obj = cls.__new__(cls)

        AsyncSkyvern.__init__(
            obj,
            environment=SkyvernEnvironment.LOCAL,
            httpx_client=create_embedded_server(
                llm_config=llm_config,
                settings_overrides=settings,
            ),
        )

        obj._environment = SkyvernEnvironment.LOCAL
        obj._api_key = None
        obj._playwright = None

        return obj

    @property
    def environment(self) -> SkyvernEnvironment | None:
        """Get the current Skyvern environment (CLOUD, STAGING, LOCAL, or None for embedded mode)."""
        return self._environment

    async def run_task(
        self,
        prompt: str,
        engine: RunEngine = RunEngine.skyvern_v2,
        model: dict[str, Any] | None = None,
        url: str | None = None,
        webhook_url: str | None = None,
        totp_identifier: str | None = None,
        totp_url: str | None = None,
        title: str | None = None,
        error_code_mapping: dict[str, str] | None = None,
        data_extraction_schema: dict[str, Any] | str | None = None,
        proxy_location: ProxyLocation | None = None,
        max_steps: int | None = None,
        wait_for_completion: bool = False,
        timeout: float = DEFAULT_AGENT_TIMEOUT,
        browser_session_id: str | None = None,
        user_agent: str | None = None,
        extra_http_headers: dict[str, str] | None = None,
        publish_workflow: bool = False,
        include_action_history_in_verification: bool | None = None,
        max_screenshot_scrolls: int | None = None,
        browser_address: str | None = None,
        request_options: RequestOptions | None = None,
    ) -> TaskRunResponse:
        task_run = await super().run_task(
            prompt=prompt,
            engine=engine,
            model=model,
            url=url,
            webhook_url=webhook_url,
            totp_identifier=totp_identifier,
            totp_url=totp_url,
            title=title,
            error_code_mapping=error_code_mapping,
            data_extraction_schema=data_extraction_schema,
            proxy_location=proxy_location,
            max_steps=max_steps,
            browser_session_id=browser_session_id,
            user_agent=user_agent,
            extra_http_headers=extra_http_headers,
            publish_workflow=publish_workflow,
            include_action_history_in_verification=include_action_history_in_verification,
            max_screenshot_scrolls=max_screenshot_scrolls,
            browser_address=browser_address,
            request_options=request_options,
        )

        if wait_for_completion:
            async with asyncio.timeout(timeout):
                while True:
                    task_run = await super().get_run(task_run.run_id)
                    if RunStatus(task_run.status).is_final():
                        break
                    await asyncio.sleep(DEFAULT_AGENT_HEARTBEAT_INTERVAL)
        return TaskRunResponse.model_validate(task_run.model_dump())

    async def run_workflow(
        self,
        workflow_id: str,
        parameters: dict[str, Any] | None = None,
        template: bool | None = None,
        title: str | None = None,
        proxy_location: ProxyLocation | None = None,
        webhook_url: str | None = None,
        totp_url: str | None = None,
        totp_identifier: str | None = None,
        browser_session_id: str | None = None,
        max_steps_override: int | None = None,
        user_agent: str | None = None,
        browser_profile_id: str | None = None,
        max_screenshot_scrolls: int | None = None,
        extra_http_headers: dict[str, str] | None = None,
        browser_address: str | None = None,
        ai_fallback: bool | None = None,
        run_with: str | None = None,
        wait_for_completion: bool = False,
        timeout: float = DEFAULT_AGENT_TIMEOUT,
        request_options: RequestOptions | None = None,
    ) -> WorkflowRunResponse:
        workflow_run = await super().run_workflow(
            workflow_id=workflow_id,
            parameters=parameters,
            template=template,
            title=title,
            proxy_location=proxy_location,
            webhook_url=webhook_url,
            totp_url=totp_url,
            totp_identifier=totp_identifier,
            browser_session_id=browser_session_id,
            max_steps_override=max_steps_override,
            user_agent=user_agent,
            browser_profile_id=browser_profile_id,
            max_screenshot_scrolls=max_screenshot_scrolls,
            extra_http_headers=extra_http_headers,
            browser_address=browser_address,
            ai_fallback=ai_fallback,
            run_with=run_with,
            request_options=request_options,
        )
        if wait_for_completion:
            async with asyncio.timeout(timeout):
                while True:
                    workflow_run = await super().get_run(workflow_run.run_id)
                    if RunStatus(workflow_run.status).is_final():
                        break
                    await asyncio.sleep(DEFAULT_AGENT_HEARTBEAT_INTERVAL)
        return WorkflowRunResponse.model_validate(workflow_run.model_dump())

    async def login(
        self,
        credential_type: CredentialType,
        *,
        url: str | None = None,
        credential_id: str | None = None,
        bitwarden_collection_id: str | None = None,
        bitwarden_item_id: str | None = None,
        onepassword_vault_id: str | None = None,
        onepassword_item_id: str | None = None,
        prompt: str | None = None,
        webhook_url: str | None = None,
        proxy_location: ProxyLocation | None = None,
        totp_identifier: str | None = None,
        totp_url: str | None = None,
        browser_session_id: str | None = None,
        browser_address: str | None = None,
        extra_http_headers: dict[str, str] | None = None,
        max_screenshot_scrolling_times: int | None = None,
        azure_vault_name: str | None = None,
        azure_vault_username_key: str | None = None,
        azure_vault_password_key: str | None = None,
        azure_vault_totp_secret_key: str | None = None,
        wait_for_completion: bool = False,
        timeout: float = DEFAULT_AGENT_TIMEOUT,
        request_options: RequestOptions | None = None,
    ) -> WorkflowRunResponse:
        workflow_run = await super().login(
            credential_type=credential_type,
            url=url,
            credential_id=credential_id,
            bitwarden_collection_id=bitwarden_collection_id,
            bitwarden_item_id=bitwarden_item_id,
            onepassword_vault_id=onepassword_vault_id,
            onepassword_item_id=onepassword_item_id,
            prompt=prompt,
            webhook_url=webhook_url,
            proxy_location=proxy_location,
            totp_identifier=totp_identifier,
            totp_url=totp_url,
            browser_session_id=browser_session_id,
            browser_address=browser_address,
            extra_http_headers=extra_http_headers,
            max_screenshot_scrolling_times=max_screenshot_scrolling_times,
            azure_vault_name=azure_vault_name,
            azure_vault_username_key=azure_vault_username_key,
            azure_vault_password_key=azure_vault_password_key,
            azure_vault_totp_secret_key=azure_vault_totp_secret_key,
            request_options=request_options,
        )
        if wait_for_completion:
            async with asyncio.timeout(timeout):
                while True:
                    workflow_run = await super().get_run(workflow_run.run_id)
                    if RunStatus(workflow_run.status).is_final():
                        break
                    await asyncio.sleep(DEFAULT_AGENT_HEARTBEAT_INTERVAL)
        return WorkflowRunResponse.model_validate(workflow_run.model_dump())

    async def launch_local_browser(
        self,
        *,
        headless: bool = False,
        port: int = DEFAULT_CDP_PORT,
        args: list[str] | None = None,
        user_data_dir: str | None = None,
    ) -> SkyvernBrowser:
        """Launch a new local Chromium browser with Chrome DevTools Protocol (CDP) enabled.

        This method launches a browser on your local machine with remote debugging enabled,
        allowing Skyvern to control it via CDP. Useful for development and debugging.

        Args:
            headless: Whether to run the browser in headless mode. Defaults to False.
            port: The port number for the CDP endpoint. Defaults to DEFAULT_CDP_PORT.
            args: Additional command-line arguments to pass to Chromium. Defaults to None.
                Example: ["--disable-blink-features=AutomationControlled", "--window-size=1920,1080"]

        Returns:
            SkyvernBrowser: A browser instance with Skyvern capabilities.
        """

        playwright = await self._get_playwright()

        if user_data_dir:
            user_data_path = pathlib.Path(user_data_dir)
        else:
            user_data_path = pathlib.Path(tempfile.gettempdir()) / "skyvern-browser"

        launch_args = [
            f"--remote-debugging-port={port}",
        ]
        if args:
            launch_args.extend(args)

        browser_context = await playwright.chromium.launch_persistent_context(
            user_data_dir=str(user_data_path),
            headless=headless,
            args=launch_args,
        )
        browser_address = f"http://localhost:{port}"
        return SkyvernBrowser(self, browser_context, browser_address=browser_address)

    async def connect_to_browser_over_cdp(self, cdp_url: str) -> SkyvernBrowser:
        """Connect to an existing browser instance via Chrome DevTools Protocol (CDP).

        Use this to connect to a browser that's already running with CDP enabled,
        whether local or remote.

        Args:
            cdp_url: The CDP WebSocket URL (e.g., "http://localhost:9222").

        Returns:
            SkyvernBrowser: A browser instance connected to the existing browser.
        """
        playwright = await self._get_playwright()
        browser = await playwright.chromium.connect_over_cdp(cdp_url)
        browser_context = browser.contexts[0] if browser.contexts else await browser.new_context()
        return SkyvernBrowser(self, browser_context, browser_address=cdp_url)

    async def connect_to_cloud_browser_session(self, browser_session_id: str) -> SkyvernBrowser:
        """Connect to an existing cloud-hosted browser session by ID.

        Args:
            browser_session_id: The ID of the cloud browser session to connect to.

        Returns:
            SkyvernBrowser: A browser instance connected to the cloud session.
        """
        self._ensure_cloud_environment()
        browser_session = await self.get_browser_session(browser_session_id)
        if self._environment == SkyvernEnvironment.CLOUD:
            LOG.info(
                "Connecting to existing cloud browser session",
                url=_get_browser_session_url(browser_session.browser_session_id),
            )
        else:
            LOG.info(
                "Connecting to existing cloud browser session", browser_session_id=browser_session.browser_session_id
            )
        return await self._connect_to_cloud_browser_session(browser_session)

    async def launch_cloud_browser(
        self,
        *,
        timeout: int | None = None,
        proxy_location: ProxyLocation | None = None,
    ) -> SkyvernBrowser:
        """Launch a new cloud-hosted browser session.

        This creates a new browser session in Skyvern's cloud infrastructure and connects to it.

        Args:
            timeout: Timeout in minutes for the session. Timeout is applied after the session is started.
                Must be between 5 and 1440. Defaults to 60.
            proxy_location: Geographic proxy location to route the browser traffic through.
                This is only available in Skyvern Cloud.

        Returns:
            SkyvernBrowser: A browser instance connected to the new cloud session.
        """
        self._ensure_cloud_environment()
        browser_session = await self.create_browser_session(
            timeout=timeout,
            proxy_location=proxy_location,
        )
        if self._environment == SkyvernEnvironment.CLOUD:
            LOG.info(
                "Launched new cloud browser session",
                url=_get_browser_session_url(browser_session.browser_session_id),
            )
        else:
            LOG.info("Launched new cloud browser session", browser_session_id=browser_session.browser_session_id)
        return await self._connect_to_cloud_browser_session(browser_session)

    async def use_cloud_browser(
        self,
        *,
        timeout: int | None = None,
        proxy_location: ProxyLocation | None = None,
    ) -> SkyvernBrowser:
        """Get or create a cloud browser session.

        This method attempts to reuse the most recent available cloud browser session.
        If no session exists, it creates a new one. This is useful for cost efficiency
        and session persistence.

        Args:
            timeout: Timeout in minutes for the session. Timeout is applied after the session is started.
                Must be between 5 and 1440. Defaults to 60. Only used when creating a new session.
            proxy_location: Geographic proxy location to route the browser traffic through.
                This is only available in Skyvern Cloud. Only used when creating a new session.

        Returns:
            SkyvernBrowser: A browser instance connected to an existing or new cloud session.
        """
        self._ensure_cloud_environment()
        browser_sessions = await self.get_browser_sessions()
        available_sessions = [
            s
            for s in browser_sessions
            if s.runnable_id is None and s.started_at is not None and s.browser_address is not None
        ]
        browser_session = max(available_sessions, key=lambda s: s.started_at, default=None)
        if browser_session is None:
            LOG.info("No existing cloud browser session found, launching a new session")
            browser_session = await self.create_browser_session(
                timeout=timeout,
                proxy_location=proxy_location,
            )
            if self._environment == SkyvernEnvironment.CLOUD:
                LOG.info(
                    "Launched new cloud browser session",
                    url=_get_browser_session_url(browser_session.browser_session_id),
                )
            else:
                LOG.info("Launched new cloud browser session", browser_session_id=browser_session.browser_session_id)
        else:
            if self._environment == SkyvernEnvironment.CLOUD:
                LOG.info(
                    "Reusing existing cloud browser session",
                    url=_get_browser_session_url(browser_session.browser_session_id),
                )
            else:
                LOG.info(
                    "Reusing existing cloud browser session", browser_session_id=browser_session.browser_session_id
                )

        return await self._connect_to_cloud_browser_session(browser_session)

    def _ensure_cloud_environment(self) -> None:
        if self._environment not in (SkyvernEnvironment.CLOUD, SkyvernEnvironment.STAGING):
            raise ValueError("Cloud browser sessions are supported only in the cloud environment")

    async def _connect_to_cloud_browser_session(self, browser_session: BrowserSessionResponse) -> SkyvernBrowser:
        if browser_session.browser_address is None:
            raise ValueError(f"Browser address is missing for session {browser_session.browser_session_id}")

        playwright = await self._get_playwright()
        browser = await playwright.chromium.connect_over_cdp(
            browser_session.browser_address, headers={"x-api-key": self._api_key}
        )
        browser_context = browser.contexts[0] if browser.contexts else await browser.new_context()
        return SkyvernBrowser(self, browser_context, browser_session_id=browser_session.browser_session_id)

    async def _get_playwright(self) -> Playwright:
        if self._playwright is None:
            self._playwright = await async_playwright().start()
        return self._playwright

    async def aclose(self) -> None:
        """Close Playwright and release resources."""
        if self._playwright is not None:
            try:
                await self._playwright.stop()
            finally:
                self._playwright = None



"""add projects table

Revision ID: f72cf593e1a7
Revises: 1d0a10ae2a13
Create Date: 2025-07-30 22:49:26.594708+00:00

"""

from typing import Sequence, Union

import sqlalchemy as sa

from alembic import op

# revision identifiers, used by Alembic.
revision: str = "f72cf593e1a7"
down_revision: Union[str, None] = "1d0a10ae2a13"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "projects",
        sa.Column("project_revision_id", sa.String(), nullable=False),
        sa.Column("project_id", sa.String(), nullable=False),
        sa.Column("organization_id", sa.String(), nullable=False),
        sa.Column("artifact_id", sa.String(), nullable=True),
        sa.Column("workflow_permanent_id", sa.String(), nullable=True),
        sa.Column("run_id", sa.String(), nullable=True),
        sa.Column("version", sa.Integer(), nullable=False),
        sa.Column("created_at", sa.DateTime(), nullable=False),
        sa.Column("modified_at", sa.DateTime(), nullable=False),
        sa.Column("deleted_at", sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint("project_revision_id"),
        sa.UniqueConstraint("organization_id", "project_id", "version", name="uc_org_project_version"),
    )
    op.create_index("project_org_created_at_index", "projects", ["organization_id", "created_at"], unique=False)
    op.create_index("project_org_run_id_index", "projects", ["organization_id", "run_id"], unique=False)
    op.create_index("project_org_wpid_index", "projects", ["organization_id", "workflow_permanent_id"], unique=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index("project_org_wpid_index", table_name="projects")
    op.drop_index("project_org_run_id_index", table_name="projects")
    op.drop_index("project_org_created_at_index", table_name="projects")
    op.drop_table("projects")
    # ### end Alembic commands ###



import os
import sys

import structlog
import uvicorn
from dotenv import load_dotenv

from skyvern import analytics
from skyvern.config import settings

LOG = structlog.stdlib.get_logger()


if __name__ == "__main__":
    analytics.capture("skyvern-oss-run-server")
    port = settings.PORT
    LOG.info("Agent server starting.", host="0.0.0.0", port=port)
    load_dotenv()

    # Disable reload on Windows - uvicorn forces WindowsSelectorEventLoopPolicy when reload=True,
    # but Windows needs WindowsProactorEventLoopPolicy for async subprocess operations
    reload = settings.ENV == "local" and sys.platform != "win32"

    # Configure reload settings
    # Convert TEMP_PATH to relative path if it's absolute to avoid pathlib.glob() issues
    temp_path_for_excludes = (
        os.path.relpath(settings.TEMP_PATH) if os.path.isabs(settings.TEMP_PATH) else settings.TEMP_PATH
    )
    artifact_path_for_excludes = (
        os.path.relpath(settings.ARTIFACT_STORAGE_PATH)
        if os.path.isabs(settings.ARTIFACT_STORAGE_PATH)
        else settings.ARTIFACT_STORAGE_PATH
    )

    uvicorn.run(
        "skyvern.forge.api_app:create_api_app",
        host="0.0.0.0",
        port=port,
        log_level="info",
        reload=reload,
        reload_excludes=[
            f"{temp_path_for_excludes}/**/*.py",
            f"{artifact_path_for_excludes}/{settings.ENV}/**/scripts/**/**/*.py",
        ],
        factory=True,
    )



import os

from dotenv import load_dotenv, set_key
from rich.panel import Panel
from rich.prompt import Confirm, Prompt

from skyvern.analytics import capture_setup_event
from skyvern.utils.env_paths import resolve_backend_env_path

from .console import console


def update_or_add_env_var(key: str, value: str) -> None:
    """Update or add environment variable in .env file."""
    env_path = resolve_backend_env_path()
    if not env_path.exists():
        env_path.touch()
        defaults = {
            "ENV": "local",
            "ENABLE_OPENAI": "false",
            "OPENAI_API_KEY": "",
            "ENABLE_ANTHROPIC": "false",
            "ANTHROPIC_API_KEY": "",
            "ENABLE_AZURE": "false",
            "AZURE_DEPLOYMENT": "",
            "AZURE_API_KEY": "",
            "AZURE_API_BASE": "",
            "AZURE_API_VERSION": "",
            "ENABLE_AZURE_GPT4O_MINI": "false",
            "AZURE_GPT4O_MINI_DEPLOYMENT": "",
            "AZURE_GPT4O_MINI_API_KEY": "",
            "AZURE_GPT4O_MINI_API_BASE": "",
            "AZURE_GPT4O_MINI_API_VERSION": "",
            "ENABLE_GEMINI": "false",
            "GEMINI_API_KEY": "",
            "ENABLE_NOVITA": "false",
            "NOVITA_API_KEY": "",
            "LLM_KEY": "",
            "SECONDARY_LLM_KEY": "",
            "BROWSER_TYPE": "chromium-headful",
            "MAX_SCRAPING_RETRIES": "0",
            "VIDEO_PATH": "./videos",
            "BROWSER_ACTION_TIMEOUT_MS": "5000",
            "MAX_STEPS_PER_RUN": "50",
            "LOG_LEVEL": "INFO",
            "LITELLM_LOG": "CRITICAL",
            "DATABASE_STRING": "postgresql+psycopg://skyvern@localhost/skyvern",
            "PORT": "8000",
            "ANALYTICS_ID": "anonymous",
            "ENABLE_LOG_ARTIFACTS": "false",
        }
        for k, v in defaults.items():
            set_key(env_path, k, v)

    load_dotenv(env_path)
    set_key(env_path, key, value)
    os.environ[key] = value


def setup_llm_providers() -> None:
    """Configure Large Language Model (LLM) Providers."""
    console.print(Panel("[bold magenta]LLM Provider Configuration[/bold magenta]", border_style="purple"))
    console.print("[italic]Note: All information provided here will be stored only on your local machine.[/italic]")
    capture_setup_event("llm-start")
    model_options: list[str] = []
    enabled_providers: list[str] = []

    console.print("\n[bold blue]--- OpenAI Configuration ---[/bold blue]")
    console.print("To enable OpenAI, you must have an OpenAI API key.")
    enable_openai = Confirm.ask("Do you want to enable OpenAI?")
    if enable_openai:
        openai_api_key = Prompt.ask("Enter your OpenAI API key", password=True)
        if not openai_api_key:
            console.print("[red]Error: OpenAI API key is required. OpenAI will not be enabled.[/red]")
        else:
            update_or_add_env_var("OPENAI_API_KEY", openai_api_key)
            update_or_add_env_var("ENABLE_OPENAI", "true")
            enabled_providers.append("openai")
            model_options.extend(
                [
                    "OPENAI_GPT5",
                    "OPENAI_GPT5_2",
                    "OPENAI_GPT4_1",
                    "OPENAI_O3",
                    "OPENAI_O4_MINI",
                    "OPENAI_GPT4O",
                ]
            )
    else:
        update_or_add_env_var("ENABLE_OPENAI", "false")

    console.print("\n[bold blue]--- Anthropic Configuration ---[/bold blue]")
    console.print("To enable Anthropic, you must have an Anthropic API key.")
    enable_anthropic = Confirm.ask("Do you want to enable Anthropic?")
    if enable_anthropic:
        anthropic_api_key = Prompt.ask("Enter your Anthropic API key", password=True)
        if not anthropic_api_key:
            console.print("[red]Error: Anthropic API key is required. Anthropic will not be enabled.[/red]")
        else:
            update_or_add_env_var("ANTHROPIC_API_KEY", anthropic_api_key)
            update_or_add_env_var("ENABLE_ANTHROPIC", "true")
            enabled_providers.append("anthropic")
            model_options.extend(
                [
                    "ANTHROPIC_CLAUDE4.5_OPUS",
                    "ANTHROPIC_CLAUDE4.5_SONNET",
                    "ANTHROPIC_CLAUDE4_OPUS",
                    "ANTHROPIC_CLAUDE4_SONNET",
                    "ANTHROPIC_CLAUDE4.5_HAIKU",
                ]
            )
    else:
        update_or_add_env_var("ENABLE_ANTHROPIC", "false")

    console.print("\n[bold blue]--- Azure Configuration ---[/bold blue]")
    console.print("To enable Azure, you must have an Azure deployment name, API key, base URL, and API version.")
    enable_azure = Confirm.ask("Do you want to enable Azure?")
    if enable_azure:
        azure_deployment = Prompt.ask("Enter your Azure deployment name")
        azure_api_key = Prompt.ask("Enter your Azure API key", password=True)
        azure_api_base = Prompt.ask("Enter your Azure API base URL")
        azure_api_version = Prompt.ask("Enter your Azure API version")
        if not all([azure_deployment, azure_api_key, azure_api_base, azure_api_version]):
            console.print("[red]Error: All Azure fields must be populated. Azure will not be enabled.[/red]")
        else:
            update_or_add_env_var("AZURE_DEPLOYMENT", azure_deployment)
            update_or_add_env_var("AZURE_API_KEY", azure_api_key)
            update_or_add_env_var("AZURE_API_BASE", azure_api_base)
            update_or_add_env_var("AZURE_API_VERSION", azure_api_version)
            update_or_add_env_var("ENABLE_AZURE", "true")
            enabled_providers.append("azure")
            model_options.append("AZURE_OPENAI")
    else:
        update_or_add_env_var("ENABLE_AZURE", "false")

    console.print("\n[bold blue]--- Gemini Configuration ---[/bold blue]")
    console.print("To enable Gemini, you must have a Gemini API key.")
    enable_gemini = Confirm.ask("Do you want to enable Gemini?")
    if enable_gemini:
        gemini_api_key = Prompt.ask("Enter your Gemini API key", password=True)
        if not gemini_api_key:
            console.print("[red]Error: Gemini API key is required. Gemini will not be enabled.[/red]")
        else:
            update_or_add_env_var("GEMINI_API_KEY", gemini_api_key)
            update_or_add_env_var("ENABLE_GEMINI", "true")
            enabled_providers.append("gemini")
    else:
        update_or_add_env_var("ENABLE_GEMINI", "false")

    console.print("\n[bold blue]--- Novita Configuration ---[/bold blue]")
    console.print("To enable Novita, you must have a Novita API key.")
    enable_novita = Confirm.ask("Do you want to enable Novita?")
    if enable_novita:
        novita_api_key = Prompt.ask("Enter your Novita API key", password=True)
        if not novita_api_key:
            console.print("[red]Error: Novita API key is required. Novita will not be enabled.[/red]")
        else:
            update_or_add_env_var("NOVITA_API_KEY", novita_api_key)
            update_or_add_env_var("ENABLE_NOVITA", "true")
            enabled_providers.append("novita")
            model_options.extend(
                [
                    "NOVITA_LLAMA_3_2_11B_VISION",
                    "NOVITA_LLAMA_3_1_8B",
                    "NOVITA_LLAMA_3_1_70B",
                    "NOVITA_LLAMA_3_1_405B",
                    "NOVITA_LLAMA_3_8B",
                    "NOVITA_LLAMA_3_70B",
                ]
            )
    else:
        update_or_add_env_var("ENABLE_NOVITA", "false")

    console.print("\n[bold blue]--- VolcEngine Configuration ---[/bold blue]")
    console.print("To enable VolcEngine, you must have a ByteDance Doubao API key.")
    enable_volcengine = Confirm.ask("Do you want to enable VolcEngine?")
    if enable_volcengine:
        volcengine_api_key = Prompt.ask("Enter your VolcEngine(ByteDance Doubao) API key", password=True)
        if not volcengine_api_key:
            console.print("[red]Error: VolcEngine key is required. VolcEngine will not be enabled.[/red]")
        else:
            update_or_add_env_var("VOLCENGINE_API_KEY", volcengine_api_key)
            update_or_add_env_var("ENABLE_VOLCENGINE", "true")
            enabled_providers.append("volcengine")
            model_options.extend(
                [
                    "VOLCENGINE_DOUBAO_SEED_1_6",
                    "VOLCENGINE_DOUBAO_SEED_1_6_FLASH",
                    "VOLCENGINE_DOUBAO_1_5_THINKING_VISION_PRO",
                ]
            )
    else:
        update_or_add_env_var("ENABLE_VOLCENGINE", "false")

    console.print("\n[bold blue]--- OpenAI-Compatible Provider Configuration ---[/bold blue]")
    console.print("To enable an OpenAI-compatible provider, you must have a model name, API key, and API base URL.")
    enable_openai_compatible = Confirm.ask("Do you want to enable an OpenAI-compatible provider?")
    if enable_openai_compatible:
        openai_compatible_model_name = Prompt.ask("Enter the model name (e.g., 'yi-34b', 'mistral-large')")
        openai_compatible_api_key = Prompt.ask("Enter your API key", password=True)
        openai_compatible_api_base = Prompt.ask("Enter the API base URL (e.g., 'https://api.together.xyz/v1')")
        openai_compatible_vision = Confirm.ask("Does this model support vision?")

        if not all([openai_compatible_model_name, openai_compatible_api_key, openai_compatible_api_base]):
            console.print(
                "[red]Error: All required fields must be populated. OpenAI-compatible provider will not be enabled.[/red]"
            )
        else:
            update_or_add_env_var("OPENAI_COMPATIBLE_MODEL_NAME", openai_compatible_model_name)
            update_or_add_env_var("OPENAI_COMPATIBLE_API_KEY", openai_compatible_api_key)
            update_or_add_env_var("OPENAI_COMPATIBLE_API_BASE", openai_compatible_api_base)
            if openai_compatible_vision:
                update_or_add_env_var("OPENAI_COMPATIBLE_SUPPORTS_VISION", "true")
            else:
                update_or_add_env_var("OPENAI_COMPATIBLE_SUPPORTS_VISION", "false")

            openai_compatible_api_version = Prompt.ask("Enter API version (optional, press enter to skip)", default="")
            if openai_compatible_api_version:
                update_or_add_env_var("OPENAI_COMPATIBLE_API_VERSION", openai_compatible_api_version)

            update_or_add_env_var("ENABLE_OPENAI_COMPATIBLE", "true")
            enabled_providers.append("openai_compatible")
            model_options.append("OPENAI_COMPATIBLE")
    else:
        update_or_add_env_var("ENABLE_OPENAI_COMPATIBLE", "false")

    if not model_options:
        capture_setup_event(
            "llm-no-provider",
            success=False,
            error_type="no_provider_enabled",
            error_message="No LLM providers were enabled during setup",
        )
        console.print(
            Panel(
                "[bold red]No LLM providers enabled.[/bold red]\n"
                "You won't be able to run Skyvern unless you enable at least one provider.\n"
                "You can re-run this script to enable providers or manually update the .env file.",
                border_style="red",
            )
        )
    else:
        console.print("\n[bold green]Available LLM models based on your selections:[/bold green]")
        for i, model in enumerate(model_options, 1):
            console.print(f"  [cyan]{i}.[/cyan] [green]{model}[/green]")

        chosen_model_idx = Prompt.ask(
            f"Choose a model by number (e.g., [cyan]1[/cyan] for [green]{model_options[0]}[/green])",
            choices=[str(i) for i in range(1, len(model_options) + 1)],
            default="1",
        )
        chosen_model = model_options[int(chosen_model_idx) - 1]
        console.print(f"🎉 [bold green]Chosen LLM Model: {chosen_model}[/bold green]")
        update_or_add_env_var("LLM_KEY", chosen_model)
        capture_setup_event(
            "llm-complete",
            success=True,
            extra_data={
                "enabled_providers": enabled_providers,
                "chosen_model": chosen_model,
                "provider_count": len(enabled_providers),
            },
        )

    console.print("✅ [green]LLM provider configurations updated in .env.[/green]")



"""Shared session operations for MCP tools and CLI commands."""

from __future__ import annotations

from dataclasses import dataclass
from typing import Any

from skyvern.schemas.runs import ProxyLocation


@dataclass
class SessionCreateResult:
    session_id: str | None
    local: bool = False
    headless: bool = False
    timeout_minutes: int | None = None


@dataclass
class SessionCloseResult:
    session_id: str | None
    closed: bool = True


@dataclass
class SessionInfo:
    session_id: str
    status: str | None
    started_at: str | None
    timeout: int | None
    runnable_id: str | None = None
    available: bool = False


async def do_session_create(
    skyvern: Any,
    timeout: int = 60,
    proxy_location: str | None = None,
    local: bool = False,
    headless: bool = False,
) -> tuple[Any, SessionCreateResult]:
    """Create browser session. Returns (browser, result)."""
    if local:
        browser = await skyvern.launch_local_browser(headless=headless)
        return browser, SessionCreateResult(session_id=None, local=True, headless=headless)

    proxy = ProxyLocation(proxy_location) if proxy_location else None
    browser = await skyvern.launch_cloud_browser(timeout=timeout, proxy_location=proxy)
    return browser, SessionCreateResult(
        session_id=browser.browser_session_id,
        timeout_minutes=timeout,
    )


async def do_session_close(skyvern: Any, session_id: str) -> SessionCloseResult:
    """Close a browser session by ID."""
    await skyvern.close_browser_session(session_id)
    return SessionCloseResult(session_id=session_id)


async def do_session_list(skyvern: Any) -> list[SessionInfo]:
    """List all browser sessions."""
    sessions = await skyvern.get_browser_sessions()
    return [
        SessionInfo(
            session_id=s.browser_session_id,
            status=s.status,
            started_at=s.started_at.isoformat() if s.started_at else None,
            timeout=s.timeout,
            runnable_id=s.runnable_id,
            available=s.runnable_id is None and s.browser_address is not None,
        )
        for s in sessions
    ]



import os
from typing import Any

import httpx
from httpx import ASGITransport

from skyvern.config import settings
from skyvern.forge.api_app import create_api_app
from skyvern.forge.sdk.api.llm.config_registry import LLMConfigRegistry
from skyvern.forge.sdk.api.llm.models import LLMConfig, LLMRouterConfig


def create_embedded_server(
    llm_config: LLMRouterConfig | LLMConfig | None = None,
    settings_overrides: dict[str, Any] | None = None,
) -> httpx.AsyncClient:
    class EmbeddedServerTransport(httpx.AsyncBaseTransport):
        def __init__(self) -> None:
            self._transport: ASGITransport | None = None
            self._api_key: str | None = None

        async def handle_async_request(self, request: httpx.Request) -> httpx.Response:
            if self._transport is None:
                settings.BROWSER_LOGS_ENABLED = False

                if llm_config:
                    LLMConfigRegistry.register_config(
                        "CUSTOM_LLM",
                        llm_config,
                    )
                    settings.LLM_KEY = "CUSTOM_LLM"

                # Apply custom settings overrides
                if settings_overrides:
                    for key, value in settings_overrides.items():
                        if hasattr(settings, key):
                            setattr(settings, key, value)
                        else:
                            raise ValueError(f"Invalid setting: {key}")

                self._api_key = os.getenv("SKYVERN_API_KEY")
                if not self._api_key:
                    raise ValueError("SKYVERN_API_KEY is not set. Provide api_key or set SKYVERN_API_KEY in .env file.")
                api_app = create_api_app()

                self._transport = ASGITransport(app=api_app)

            if self._api_key and "x-api-key" not in request.headers:
                request.headers["x-api-key"] = self._api_key

            response = await self._transport.handle_async_request(request)
            return response

    return httpx.AsyncClient(transport=EmbeddedServerTransport(), base_url="http://skyvern-embedded")



import smtplib
from email.message import EmailMessage

import structlog
from email_validator import EmailNotValidError, validate_email

from skyvern.forge.sdk.settings_manager import SettingsManager

LOG = structlog.get_logger()


async def _send(*, message: EmailMessage) -> bool:
    settings = SettingsManager.get_settings()
    try:
        smtp_host = smtplib.SMTP(settings.SMTP_HOST, settings.SMTP_PORT)

        LOG.info("email: Connected to SMTP server")

        smtp_host.starttls()
        smtp_host.login(settings.SMTP_USERNAME, settings.SMTP_PASSWORD)

        LOG.info("email: Logged in to SMTP server")

        smtp_host.send_message(message)

        LOG.info("email: Email sent")
    except Exception as e:
        LOG.error("email: Failed to send email", error=str(e), host=settings.SMTP_HOST, port=settings.SMTP_PORT)
        raise e

    return True


def validate_recipients(recipients: list[str]) -> None:
    for recipient in recipients:
        try:
            validate_email(recipient)
        except EmailNotValidError:
            raise Exception(
                f"invalid email address: {recipient}",
            )


async def build_message(
    *,
    body: str | None = None,
    recipients: list[str],
    sender: str,
    subject: str,
) -> EmailMessage:
    to = ", ".join(recipients)
    msg = EmailMessage()
    msg["BCC"] = sender  # BCC the sender so there is a record of the email being sent
    msg["From"] = sender
    msg["Subject"] = subject
    msg["To"] = to
    msg.set_content(body)

    return msg


async def send(
    *,
    sender: str,
    subject: str,
    recipients: list[str],
    body: str | None = None,
) -> bool:
    validate_recipients(recipients)

    message = await build_message(
        body=body,
        recipients=recipients,
        sender=sender,
        subject=subject,
    )

    return await _send(message=message)
